@@ -1,21 +1,22 @@
-//! Types for the *m.call.hangup* event.
+//! Types for the [`m.call.hangup`] event.
+//!
+//! [`m.call.hangup`]: https://spec.matrix.org/v1.2/client-server-api/#mcallhangup
 
 use js_int::UInt;
 use ruma_events_macros::EventContent;
 use ruma_serde::StringEnum;
 use serde::{Deserialize, Serialize};
 
-use crate::MessageEvent;
+use crate::PrivOwnedStr;
 
+/// The content of an `m.call.hangup` event.
+///
 /// Sent by either party to signal their termination of the call. This can be sent either once the
 /// call has has been established or before to abort the call.
-pub type HangupEvent = MessageEvent<HangupEventContent>;
-
-/// The payload for `HangupEvent`.
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[ruma_event(type = "m.call.hangup", kind = Message)]
-pub struct HangupEventContent {
+pub struct CallHangupEventContent {
     /// The ID of the call this event relates to.
     pub call_id: String,
 
@@ -27,7 +28,7 @@ pub struct HangupEventContent {
     pub reason: Option<Reason>,
 }
 
-impl HangupEventContent {
+impl CallHangupEventContent {
     /// Creates a new `HangupEventContent` with the given call ID and VoIP version.
     pub fn new(call_id: String, version: UInt) -> Self {
         Self { call_id, version, reason: None }
@@ -36,8 +37,8 @@ impl HangupEventContent {
 
 /// A reason for a hangup.
 ///
-/// This should not be provided when the user naturally ends or rejects the call. When there was an
-/// error in the call negotiation, this should be `ice_failed` for when ICE negotiation fails or
+/// Should not be provided when the user naturally ends or rejects the call. When there was an error
+/// in the call negotiation, this should be `ice_failed` for when ICE negotiation fails or
 /// `invite_timeout` for when the other party did not answer in time.
 ///
 /// This type can hold an arbitrary string. To check for formats that are not available as a
@@ -53,7 +54,7 @@ pub enum Reason {
     InviteTimeout,
 
     #[doc(hidden)]
-    _Custom(String),
+    _Custom(PrivOwnedStr),
 }
 
 impl Reason {
