@@ -1,4 +1,6 @@
-//! Types for the *m.direct* event.
+//! Types for the [`m.direct`] event.
+//!
+//! [`m.direct`]: https://spec.matrix.org/v1.2/client-server-api/#mdirect
 
 use std::{
     collections::BTreeMap,
@@ -9,20 +11,19 @@ use ruma_events_macros::EventContent;
 use ruma_identifiers::{RoomId, UserId};
 use serde::{Deserialize, Serialize};
 
-/// Informs the client about the rooms that are considered direct by a user.
-pub type DirectEvent = crate::GlobalAccountDataEvent<DirectEventContent>;
-
-/// The payload for `DirectEvent`.
+/// The content of an `m.direct` event.
 ///
-/// A mapping of `UserId`s to a list of `RoomId`s which are considered *direct* for that
-/// particular user.
+/// A mapping of `UserId`s to a list of `RoomId`s which are considered *direct* for that particular
+/// user.
+///
+/// Informs the client about the rooms that are considered direct by a user.
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
 #[allow(clippy::exhaustive_structs)]
 #[ruma_event(type = "m.direct", kind = GlobalAccountData)]
-pub struct DirectEventContent(pub BTreeMap<UserId, Vec<RoomId>>);
+pub struct DirectEventContent(pub BTreeMap<Box<UserId>, Vec<Box<RoomId>>>);
 
 impl Deref for DirectEventContent {
-    type Target = BTreeMap<UserId, Vec<RoomId>>;
+    type Target = BTreeMap<Box<UserId>, Vec<Box<RoomId>>>;
 
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -37,10 +38,9 @@ impl DerefMut for DirectEventContent {
 
 #[cfg(test)]
 mod tests {
-    use std::{collections::BTreeMap, convert::TryFrom};
+    use std::collections::BTreeMap;
 
-    use ruma_identifiers::{RoomId, ServerName, UserId};
-    use ruma_serde::Raw;
+    use ruma_identifiers::{server_name, RoomId, UserId};
     use serde_json::{from_value as from_json_value, json, to_value as to_json_value};
 
     use super::{DirectEvent, DirectEventContent};
@@ -48,7 +48,7 @@ mod tests {
     #[test]
     fn serialization() {
         let mut content = DirectEventContent(BTreeMap::new());
-        let server_name = <&ServerName>::try_from("ruma.io").unwrap();
+        let server_name = server_name!("ruma.io");
         let alice = UserId::new(server_name);
         let room = vec![RoomId::new(server_name)];
 
@@ -67,7 +67,7 @@ mod tests {
 
     #[test]
     fn deserialization() {
-        let server_name = <&ServerName>::try_from("ruma.io").unwrap();
+        let server_name = server_name!("ruma.io");
         let alice = UserId::new(server_name);
         let rooms = vec![RoomId::new(server_name), RoomId::new(server_name)];
 
@@ -78,8 +78,7 @@ mod tests {
             "type": "m.direct"
         });
 
-        let event: DirectEvent =
-            from_json_value::<Raw<_>>(json_data).unwrap().deserialize().unwrap();
+        let event: DirectEvent = from_json_value(json_data).unwrap();
         let direct_rooms = event.content.get(&alice).unwrap();
 
         assert!(direct_rooms.contains(&rooms[0]));
