@@ -1,62 +1,63 @@
-//! Types for the *m.key.verification.start* event.
+//! Types for the [`m.key.verification.start`] event.
+//!
+//! [`m.key.verification.start`]: https://spec.matrix.org/v1.2/client-server-api/#mkeyverificationstart
 
 use std::collections::BTreeMap;
 
 use ruma_events_macros::EventContent;
-use ruma_identifiers::DeviceIdBox;
+use ruma_identifiers::{DeviceId, TransactionId};
+use ruma_serde::Base64;
 use serde::{Deserialize, Serialize};
 use serde_json::Value as JsonValue;
 
-#[cfg(feature = "unstable-pre-spec")]
-use super::Relation;
 use super::{
-    HashAlgorithm, KeyAgreementProtocol, MessageAuthenticationCode, ShortAuthenticationString,
+    HashAlgorithm, KeyAgreementProtocol, MessageAuthenticationCode, Relation,
+    ShortAuthenticationString,
 };
-#[cfg(feature = "unstable-pre-spec")]
-use crate::MessageEvent;
 
+/// The content of a to-device `m.key.verification.start` event.
+///
 /// Begins an SAS key verification process.
-#[cfg(feature = "unstable-pre-spec")]
-#[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
-pub type StartEvent = MessageEvent<StartEventContent>;
-
-/// The payload of a to-device *m.key.verification.start* event.
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[ruma_event(type = "m.key.verification.start", kind = ToDevice)]
-pub struct StartToDeviceEventContent {
+pub struct ToDeviceKeyVerificationStartEventContent {
     /// The device ID which is initiating the process.
-    pub from_device: DeviceIdBox,
+    pub from_device: Box<DeviceId>,
 
     /// An opaque identifier for the verification process.
     ///
     /// Must be unique with respect to the devices involved. Must be the same as the
-    /// `transaction_id` given in the *m.key.verification.request* if this process is originating
+    /// `transaction_id` given in the `m.key.verification.request` if this process is originating
     /// from a request.
-    pub transaction_id: String,
+    pub transaction_id: Box<TransactionId>,
 
     /// Method specific content.
     #[serde(flatten)]
     pub method: StartMethod,
 }
 
-impl StartToDeviceEventContent {
-    /// Creates a new `StartToDeviceEventContent` with the given device ID, transaction ID and
-    /// method specific content.
-    pub fn new(from_device: DeviceIdBox, transaction_id: String, method: StartMethod) -> Self {
+impl ToDeviceKeyVerificationStartEventContent {
+    /// Creates a new `ToDeviceKeyVerificationStartEventContent` with the given device ID,
+    /// transaction ID and method specific content.
+    pub fn new(
+        from_device: Box<DeviceId>,
+        transaction_id: Box<TransactionId>,
+        method: StartMethod,
+    ) -> Self {
         Self { from_device, transaction_id, method }
     }
 }
 
-/// The payload of an in-room *m.key.verification.start* event.
+/// The content of an in-room `m.key.verification.start` event.
+///
+/// Begins an SAS key verification process.
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
-#[cfg(feature = "unstable-pre-spec")]
-#[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[ruma_event(type = "m.key.verification.start", kind = Message)]
-pub struct StartEventContent {
+pub struct KeyVerificationStartEventContent {
     /// The device ID which is initiating the process.
-    pub from_device: DeviceIdBox,
+    pub from_device: Box<DeviceId>,
 
     /// Method specific content.
     #[serde(flatten)]
@@ -67,28 +68,27 @@ pub struct StartEventContent {
     pub relates_to: Relation,
 }
 
-#[cfg(feature = "unstable-pre-spec")]
-impl StartEventContent {
-    /// Creates a new `StartEventContent` with the given device ID, method and relation.
-    pub fn new(from_device: DeviceIdBox, method: StartMethod, relates_to: Relation) -> Self {
+impl KeyVerificationStartEventContent {
+    /// Creates a new `KeyVerificationStartEventContent` with the given device ID, method and
+    /// relation.
+    pub fn new(from_device: Box<DeviceId>, method: StartMethod, relates_to: Relation) -> Self {
         Self { from_device, method, relates_to }
     }
 }
 
-/// An enum representing the different method specific *m.key.verification.start* content.
+/// An enum representing the different method specific `m.key.verification.start` content.
 #[derive(Clone, Debug, Deserialize, Serialize)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[serde(untagged)]
 pub enum StartMethod {
-    /// The *m.sas.v1* verification method.
+    /// The `m.sas.v1` verification method.
     SasV1(SasV1Content),
 
-    /// The *m.reciprocate.v1* verification method.
+    /// The `m.reciprocate.v1` verification method.
     ///
-    /// The spec entry for this method can be found [here][1].
+    /// The spec entry for this method can be found [here].
     ///
-    /// [1]: https://spec.matrix.org/unstable/client-server-api/#mkeyverificationstartmreciprocatev1
-    #[cfg(feature = "unstable-pre-spec")]
+    /// [here]: https://spec.matrix.org/v1.2/client-server-api/#mkeyverificationstartmreciprocatev1
     ReciprocateV1(ReciprocateV1Content),
 
     /// Any unknown start method.
@@ -109,28 +109,25 @@ pub struct _CustomContent {
     pub data: BTreeMap<String, JsonValue>,
 }
 
-/// The payload of an *m.key.verification.start* event using the *m.sas.v1* method.
+/// The payload of an `m.key.verification.start` event using the `m.sas.v1` method.
 #[derive(Clone, Debug, Deserialize, Serialize)]
-#[cfg(feature = "unstable-pre-spec")]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[serde(rename = "m.reciprocate.v1", tag = "method")]
 pub struct ReciprocateV1Content {
     /// The shared secret from the QR code, encoded using unpadded base64.
-    pub secret: String,
+    pub secret: Base64,
 }
 
-#[cfg(feature = "unstable-pre-spec")]
 impl ReciprocateV1Content {
     /// Create a new `ReciprocateV1Content` with the given shared secret.
     ///
-    /// The shared secret needs to come from the scanned QR code, encoded using
-    /// unpadded base64.
-    pub fn new(secret: String) -> Self {
+    /// The shared secret needs to come from the scanned QR code, encoded using unpadded base64.
+    pub fn new(secret: Base64) -> Self {
         Self { secret }
     }
 }
 
-/// The payload of an *m.key.verification.start* event using the *m.sas.v1* method.
+/// The payload of an `m.key.verification.start` event using the `m.sas.v1` method.
 ///
 /// To create an instance of this type, first create a `SasV1ContentInit` and convert it via
 /// `SasV1Content::from` / `.into()`.
@@ -204,28 +201,23 @@ mod tests {
     use std::collections::BTreeMap;
 
     use matches::assert_matches;
-    #[cfg(feature = "unstable-pre-spec")]
-    use ruma_identifiers::event_id;
-    use ruma_identifiers::user_id;
-    use ruma_serde::Raw;
+    use ruma_identifiers::{event_id, user_id};
+    use ruma_serde::Base64;
     use serde_json::{
         from_value as from_json_value, json, to_value as to_json_value, Value as JsonValue,
     };
 
     use super::{
-        HashAlgorithm, KeyAgreementProtocol, MessageAuthenticationCode, SasV1Content,
-        SasV1ContentInit, ShortAuthenticationString, StartMethod, StartToDeviceEventContent,
+        HashAlgorithm, KeyAgreementProtocol, KeyVerificationStartEventContent,
+        MessageAuthenticationCode, ReciprocateV1Content, SasV1Content, SasV1ContentInit,
+        ShortAuthenticationString, StartMethod, ToDeviceKeyVerificationStartEventContent,
         _CustomContent,
     };
-    #[cfg(feature = "unstable-pre-spec")]
-    use super::{ReciprocateV1Content, StartEventContent};
-    #[cfg(feature = "unstable-pre-spec")]
-    use crate::key::verification::Relation;
-    use crate::ToDeviceEvent;
+    use crate::{key::verification::Relation, ToDeviceEvent};
 
     #[test]
     fn serialization() {
-        let key_verification_start_content = StartToDeviceEventContent {
+        let key_verification_start_content = ToDeviceKeyVerificationStartEventContent {
             from_device: "123".into(),
             transaction_id: "456".into(),
             method: StartMethod::SasV1(
@@ -239,7 +231,7 @@ mod tests {
             ),
         };
 
-        let sender = user_id!("@example:localhost");
+        let sender = user_id!("@example:localhost").to_owned();
 
         let json_data = json!({
             "content": {
@@ -260,7 +252,7 @@ mod tests {
 
         assert_eq!(to_json_value(&key_verification_start).unwrap(), json_data);
 
-        let sender = user_id!("@example:localhost");
+        let sender = user_id!("@example:localhost").to_owned();
 
         let json_data = json!({
             "content": {
@@ -273,7 +265,7 @@ mod tests {
             "sender": sender
         });
 
-        let key_verification_start_content = StartToDeviceEventContent {
+        let key_verification_start_content = ToDeviceKeyVerificationStartEventContent {
             from_device: "123".into(),
             transaction_id: "456".into(),
             method: StartMethod::_Custom(_CustomContent {
@@ -289,11 +281,10 @@ mod tests {
 
         assert_eq!(to_json_value(&key_verification_start).unwrap(), json_data);
 
-        #[cfg(feature = "unstable-pre-spec")]
         {
-            let secret = "This is a secret to everybody".to_owned();
+            let secret = Base64::new(b"This is a secret to everybody".to_vec());
 
-            let key_verification_start_content = StartToDeviceEventContent {
+            let key_verification_start_content = ToDeviceKeyVerificationStartEventContent {
                 from_device: "123".into(),
                 transaction_id: "456".into(),
                 method: StartMethod::ReciprocateV1(ReciprocateV1Content::new(secret.clone())),
@@ -311,13 +302,12 @@ mod tests {
     }
 
     #[test]
-    #[cfg(feature = "unstable-pre-spec")]
     fn in_room_serialization() {
         let event_id = event_id!("$1598361704261elfgc:localhost");
 
-        let key_verification_start_content = StartEventContent {
+        let key_verification_start_content = KeyVerificationStartEventContent {
             from_device: "123".into(),
-            relates_to: Relation { event_id: event_id.clone() },
+            relates_to: Relation { event_id: event_id.to_owned() },
             method: StartMethod::SasV1(
                 SasV1ContentInit {
                     hashes: vec![HashAlgorithm::Sha256],
@@ -344,11 +334,11 @@ mod tests {
 
         assert_eq!(to_json_value(&key_verification_start_content).unwrap(), json_data);
 
-        let secret = "This is a secret to everybody".to_owned();
+        let secret = Base64::new(b"This is a secret to everybody".to_vec());
 
-        let key_verification_start_content = StartEventContent {
+        let key_verification_start_content = KeyVerificationStartEventContent {
             from_device: "123".into(),
-            relates_to: Relation { event_id: event_id.clone() },
+            relates_to: Relation { event_id: event_id.to_owned() },
             method: StartMethod::ReciprocateV1(ReciprocateV1Content::new(secret.clone())),
         };
 
@@ -379,11 +369,8 @@ mod tests {
 
         // Deserialize the content struct separately to verify `TryFromRaw` is implemented for it.
         assert_matches!(
-            from_json_value::<Raw<StartToDeviceEventContent>>(json)
-                .unwrap()
-                .deserialize()
-                .unwrap(),
-            StartToDeviceEventContent {
+            from_json_value::<ToDeviceKeyVerificationStartEventContent>(json).unwrap(),
+            ToDeviceKeyVerificationStartEventContent {
                 from_device,
                 transaction_id,
                 method: StartMethod::SasV1(SasV1Content {
@@ -417,13 +404,10 @@ mod tests {
         });
 
         assert_matches!(
-            from_json_value::<Raw<ToDeviceEvent<StartToDeviceEventContent>>>(json)
-                .unwrap()
-                .deserialize()
-                .unwrap(),
+            from_json_value::<ToDeviceEvent<ToDeviceKeyVerificationStartEventContent>>(json).unwrap(),
             ToDeviceEvent {
                 sender,
-                content: StartToDeviceEventContent {
+                content: ToDeviceKeyVerificationStartEventContent {
                     from_device,
                     transaction_id,
                     method: StartMethod::SasV1(SasV1Content {
@@ -456,13 +440,10 @@ mod tests {
         });
 
         assert_matches!(
-            from_json_value::<Raw<ToDeviceEvent<StartToDeviceEventContent>>>(json)
-                .unwrap()
-                .deserialize()
-                .unwrap(),
+            from_json_value::<ToDeviceEvent<ToDeviceKeyVerificationStartEventContent>>(json).unwrap(),
             ToDeviceEvent {
                 sender,
-                content: StartToDeviceEventContent {
+                content: ToDeviceKeyVerificationStartEventContent {
                     from_device,
                     transaction_id,
                     method: StartMethod::_Custom(_CustomContent { method, data })
@@ -474,13 +455,12 @@ mod tests {
                 && data.get("test").unwrap() == &JsonValue::from("field")
         );
 
-        #[cfg(feature = "unstable-pre-spec")]
         {
             let json = json!({
                 "content": {
                     "from_device": "123",
                     "method": "m.reciprocate.v1",
-                    "secret": "It's a secret to everybody",
+                    "secret": "c2VjcmV0Cg",
                     "transaction_id": "456",
                 },
                 "type": "m.key.verification.start",
@@ -488,13 +468,10 @@ mod tests {
             });
 
             assert_matches!(
-                from_json_value::<Raw<ToDeviceEvent<StartToDeviceEventContent>>>(json)
-                    .unwrap()
-                    .deserialize()
-                    .unwrap(),
+                from_json_value::<ToDeviceEvent<ToDeviceKeyVerificationStartEventContent>>(json).unwrap(),
                 ToDeviceEvent {
                     sender,
-                    content: StartToDeviceEventContent {
+                    content: ToDeviceKeyVerificationStartEventContent {
                         from_device,
                         transaction_id,
                         method: StartMethod::ReciprocateV1(ReciprocateV1Content { secret }),
@@ -502,13 +479,12 @@ mod tests {
                 } if from_device == "123"
                     && sender == user_id!("@example:localhost")
                     && transaction_id == "456"
-                    && secret == "It's a secret to everybody"
+                    && secret.encode() == "c2VjcmV0Cg"
             );
         }
     }
 
     #[test]
-    #[cfg(feature = "unstable-pre-spec")]
     fn in_room_deserialization() {
         let id = event_id!("$1598361704261elfgc:localhost");
 
@@ -527,11 +503,8 @@ mod tests {
 
         // Deserialize the content struct separately to verify `TryFromRaw` is implemented for it.
         assert_matches!(
-            from_json_value::<Raw<StartEventContent>>(json)
-                .unwrap()
-                .deserialize()
-                .unwrap(),
-            StartEventContent {
+            from_json_value::<KeyVerificationStartEventContent>(json).unwrap(),
+            KeyVerificationStartEventContent {
                 from_device,
                 relates_to: Relation { event_id },
                 method: StartMethod::SasV1(SasV1Content {
@@ -551,7 +524,7 @@ mod tests {
         let json = json!({
             "from_device": "123",
             "method": "m.reciprocate.v1",
-            "secret": "It's a secret to everybody",
+            "secret": "c2VjcmV0Cg",
             "m.relates_to": {
                 "rel_type": "m.reference",
                 "event_id": id,
@@ -559,17 +532,14 @@ mod tests {
         });
 
         assert_matches!(
-            from_json_value::<Raw<StartEventContent>>(json)
-                .unwrap()
-                .deserialize()
-                .unwrap(),
-            StartEventContent {
+            from_json_value::<KeyVerificationStartEventContent>(json).unwrap(),
+            KeyVerificationStartEventContent {
                 from_device,
                 relates_to: Relation { event_id },
                 method: StartMethod::ReciprocateV1(ReciprocateV1Content { secret }),
             } if from_device == "123"
                 && event_id == id
-                && secret == "It's a secret to everybody"
+                && secret.encode() == "c2VjcmV0Cg"
         );
     }
 }
