@@ -1,18 +1,19 @@
-//! Types for the *m.policy.rule.room* event.
+//! Types for the [`m.policy.rule.room`] event.
+//!
+//! [`m.policy.rule.room`]: https://spec.matrix.org/v1.2/client-server-api/#mpolicyruleroom
 
 use ruma_events_macros::EventContent;
 use serde::{Deserialize, Serialize};
 
-use crate::{policy::rule::PolicyRuleEventContent, StateEvent};
+use crate::policy::rule::PolicyRuleEventContent;
 
+/// The content of an `m.policy.rule.room` event.
+///
 /// This event type is used to apply rules to room entities.
-pub type RoomEvent = StateEvent<RoomEventContent>;
-
-/// The payload for `RoomEvent`.
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
 #[allow(clippy::exhaustive_structs)]
 #[ruma_event(type = "m.policy.rule.room", kind = State)]
-pub struct RoomEventContent(pub PolicyRuleEventContent);
+pub struct PolicyRuleRoomEventContent(pub PolicyRuleEventContent);
 
 #[cfg(test)]
 mod tests {
@@ -24,7 +25,7 @@ mod tests {
     use ruma_serde::Raw;
     use serde_json::{from_value as from_json_value, json, to_value as to_json_value};
 
-    use super::{RoomEvent, RoomEventContent};
+    use super::{PolicyRuleRoomEvent, PolicyRuleRoomEventContent};
     use crate::{
         policy::rule::{PolicyRuleEventContent, Recommendation},
         Unsigned,
@@ -32,20 +33,20 @@ mod tests {
 
     #[test]
     fn serialization() {
-        let room_event = RoomEvent {
-            event_id: event_id!("$143273582443PhrSn:example.org"),
-            sender: user_id!("@example:example.org"),
+        let room_event = PolicyRuleRoomEvent {
+            event_id: event_id!("$143273582443PhrSn:example.org").to_owned(),
+            sender: user_id!("@example:example.org").to_owned(),
             origin_server_ts: MilliSecondsSinceUnixEpoch(1_432_735_824_653_u64.try_into().unwrap()),
-            room_id: room_id!("!jEsUZKDJdhlrceRyVU:example.org"),
+            room_id: room_id!("!jEsUZKDJdhlrceRyVU:example.org").to_owned(),
             state_key: "rule:#*:example.org".into(),
             prev_content: None,
             unsigned: Unsigned {
                 age: Some(int!(1234)),
                 transaction_id: None,
-                #[cfg(feature = "unstable-pre-spec")]
+                #[cfg(feature = "unstable-msc2675")]
                 relations: None,
             },
-            content: RoomEventContent(PolicyRuleEventContent {
+            content: PolicyRuleRoomEventContent(PolicyRuleEventContent {
                 entity: "#*:example.org".into(),
                 reason: "undesirable content".into(),
                 recommendation: Recommendation::Ban,
@@ -91,6 +92,6 @@ mod tests {
             }
         });
 
-        assert!(from_json_value::<Raw<RoomEvent>>(json).unwrap().deserialize().is_ok());
+        assert!(from_json_value::<Raw<PolicyRuleRoomEvent>>(json).unwrap().deserialize().is_ok());
     }
 }
