@@ -8,6 +8,7 @@ use serde::{Deserialize, Serialize};
 
 /// Summary of all reactions with the given key to an event.
 #[derive(Clone, Debug, Default, Deserialize, PartialEq, Eq, Serialize)]
+#[cfg(feature = "unstable-msc2677")]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 pub struct BundledReaction {
     /// The key (emoji) used for reaction.
@@ -21,6 +22,7 @@ pub struct BundledReaction {
     pub count: UInt,
 }
 
+#[cfg(feature = "unstable-msc2677")]
 impl BundledReaction {
     /// Creates a new `BundledReaction`.
     pub fn new(
@@ -34,6 +36,7 @@ impl BundledReaction {
 
 /// Type of bundled annotation.
 #[derive(Clone, Debug, Deserialize, Serialize)]
+#[cfg(feature = "unstable-msc2677")]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[serde(tag = "type")]
 pub enum BundledAnnotation {
@@ -44,6 +47,7 @@ pub enum BundledAnnotation {
 
 /// The first chunk of annotations with a token for loading more.
 #[derive(Clone, Debug, Default, Deserialize, Serialize)]
+#[cfg(feature = "unstable-msc2677")]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 pub struct AnnotationChunk {
     /// The first batch of bundled annotations.
@@ -54,6 +58,7 @@ pub struct AnnotationChunk {
     pub next_batch: Option<String>,
 }
 
+#[cfg(feature = "unstable-msc2677")]
 impl AnnotationChunk {
     /// Creates a new `AnnotationChunk` with the given chunk and next batch token.
     pub fn new(chunk: Vec<BundledAnnotation>, next_batch: Option<String>) -> Self {
@@ -66,13 +71,26 @@ impl AnnotationChunk {
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 pub struct Relations {
     /// Annotation relations.
+    #[cfg(feature = "unstable-msc2677")]
     #[serde(rename = "m.annotation")]
     pub annotation: Option<AnnotationChunk>,
 }
 
 impl Relations {
+    #[cfg(feature = "unstable-msc2677")]
     /// Creates a new `Relations` with the given annotation.
+    ///
+    /// Without the `unstable-msc-2677` feature, this method doesn't have any
+    /// parameters.
     pub fn new(annotation: Option<AnnotationChunk>) -> Self {
         Self { annotation }
     }
+
+    #[cfg(not(feature = "unstable-msc2677"))]
+    /// Creates a new empty `Relations`.
+    ///
+    /// With the `unstable-msc-2677` feature, this method takes an annotation.
+    pub fn new() -> Self {
+        Self {}
+    }
 }
