@@ -1,4 +1,4 @@
-//! Types for the *m.room.aliases* event.
+//! Types for the `m.room.aliases` event.
 
 use ruma_events_macros::EventContent;
 use ruma_identifiers::{RoomAliasId, RoomVersionId};
@@ -7,63 +7,62 @@ use serde_json::value::RawValue as RawJsonValue;
 
 use crate::{
     EventContent, HasDeserializeFields, RedactContent, RedactedEventContent,
-    RedactedStateEventContent, StateEvent,
+    RedactedStateEventContent,
 };
 
+/// The content of an `m.room.aliases` event.
+///
 /// Informs the room about what room aliases it has been given.
-pub type AliasesEvent = StateEvent<AliasesEventContent>;
-
-/// The payload for `AliasesEvent`.
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[ruma_event(type = "m.room.aliases", kind = State, custom_redacted)]
-pub struct AliasesEventContent {
+pub struct RoomAliasesEventContent {
     /// A list of room aliases.
-    pub aliases: Vec<RoomAliasId>,
+    pub aliases: Vec<Box<RoomAliasId>>,
 }
 
-impl AliasesEventContent {
-    /// Create an `AliasesEventContent` from the given aliases.
-    pub fn new(aliases: Vec<RoomAliasId>) -> Self {
+impl RoomAliasesEventContent {
+    /// Create an `RoomAliasesEventContent` from the given aliases.
+    pub fn new(aliases: Vec<Box<RoomAliasId>>) -> Self {
         Self { aliases }
     }
 }
 
-impl RedactContent for AliasesEventContent {
-    type Redacted = RedactedAliasesEventContent;
+impl RedactContent for RoomAliasesEventContent {
+    type Redacted = RedactedRoomAliasesEventContent;
 
-    fn redact(self, version: &RoomVersionId) -> RedactedAliasesEventContent {
+    fn redact(self, version: &RoomVersionId) -> RedactedRoomAliasesEventContent {
         // We compare the long way to avoid pre version 6 behavior if/when
         // a new room version is introduced.
         let aliases = match version {
-            RoomVersionId::Version1
-            | RoomVersionId::Version2
-            | RoomVersionId::Version3
-            | RoomVersionId::Version4
-            | RoomVersionId::Version5 => Some(self.aliases),
+            RoomVersionId::V1
+            | RoomVersionId::V2
+            | RoomVersionId::V3
+            | RoomVersionId::V4
+            | RoomVersionId::V5 => Some(self.aliases),
             _ => None,
         };
 
-        RedactedAliasesEventContent { aliases }
+        RedactedRoomAliasesEventContent { aliases }
     }
 }
 
 /// An aliases event that has been redacted.
 #[derive(Clone, Debug, Default, Deserialize, Serialize)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
-pub struct RedactedAliasesEventContent {
+pub struct RedactedRoomAliasesEventContent {
     /// A list of room aliases.
     ///
     /// According to the Matrix spec version 1 redaction rules allowed this field to be
     /// kept after redaction, this was changed in version 6.
-    pub aliases: Option<Vec<RoomAliasId>>,
+    pub aliases: Option<Vec<Box<RoomAliasId>>>,
 }
 
-impl RedactedAliasesEventContent {
+impl RedactedRoomAliasesEventContent {
     /// Create a `RedactedAliasesEventContent` with the given aliases.
     ///
     /// This is only valid for room version 5 and below.
-    pub fn new_v1(aliases: Vec<RoomAliasId>) -> Self {
+    pub fn new_v1(aliases: Vec<Box<RoomAliasId>>) -> Self {
         Self { aliases: Some(aliases) }
     }
 
@@ -75,7 +74,7 @@ impl RedactedAliasesEventContent {
     }
 }
 
-impl EventContent for RedactedAliasesEventContent {
+impl EventContent for RedactedRoomAliasesEventContent {
     fn event_type(&self) -> &str {
         "m.room.aliases"
     }
@@ -94,7 +93,7 @@ impl EventContent for RedactedAliasesEventContent {
 
 // Since this redacted event has fields we leave the default `empty` method
 // that will error if called.
-impl RedactedEventContent for RedactedAliasesEventContent {
+impl RedactedEventContent for RedactedRoomAliasesEventContent {
     fn has_serialize_fields(&self) -> bool {
         self.aliases.is_some()
     }
@@ -104,4 +103,4 @@ impl RedactedEventContent for RedactedAliasesEventContent {
     }
 }
 
-impl RedactedStateEventContent for RedactedAliasesEventContent {}
+impl RedactedStateEventContent for RedactedRoomAliasesEventContent {}
