@@ -1,4 +1,6 @@
-//! Types for the *m.room.avatar* event.
+//! Types for the [`m.room.avatar`] event.
+//!
+//! [`m.room.avatar`]: https://spec.matrix.org/v1.2/client-server-api/#mroomavatar
 
 use js_int::UInt;
 use ruma_events_macros::EventContent;
@@ -6,19 +8,17 @@ use ruma_identifiers::MxcUri;
 use serde::{Deserialize, Serialize};
 
 use super::ThumbnailInfo;
-use crate::StateEvent;
 
+/// The content of an `m.room.avatar` event.
+///
 /// A picture that is associated with the room.
 ///
 /// This can be displayed alongside the room information.
-pub type AvatarEvent = StateEvent<AvatarEventContent>;
-
-/// The payload for `AvatarEvent`.
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[cfg_attr(feature = "unstable-pre-spec", derive(Default))]
 #[ruma_event(type = "m.room.avatar", kind = State)]
-pub struct AvatarEventContent {
+pub struct RoomAvatarEventContent {
     /// Information about the avatar image.
     #[serde(skip_serializing_if = "Option::is_none")]
     pub info: Option<Box<ImageInfo>>,
@@ -26,28 +26,32 @@ pub struct AvatarEventContent {
     /// URL of the avatar image.
     ///
     /// With the `unstable-pre-spec` feature, this field is optional.
+    /// See [matrix-doc#2006](https://github.com/matrix-org/matrix-doc/issues/2006).
     #[cfg(not(feature = "unstable-pre-spec"))]
-    pub url: MxcUri,
+    pub url: Box<MxcUri>,
 
     /// URL of the avatar image.
     ///
     /// Without the `unstable-pre-spec` feature, this field is not optional.
+    /// See [matrix-doc#2006](https://github.com/matrix-org/matrix-doc/issues/2006).
     #[cfg(feature = "unstable-pre-spec")]
-    pub url: Option<MxcUri>,
+    pub url: Option<Box<MxcUri>>,
 }
 
-impl AvatarEventContent {
-    /// Create an `AvatarEventContent` from the given image URL.
+impl RoomAvatarEventContent {
+    /// Create an `RoomAvatarEventContent` from the given image URL.
     ///
     /// With the `unstable-pre-spec` feature, this method takes no parameters.
+    /// See [matrix-doc#2006](https://github.com/matrix-org/matrix-doc/issues/2006).
     #[cfg(not(feature = "unstable-pre-spec"))]
-    pub fn new(url: MxcUri) -> Self {
+    pub fn new(url: Box<MxcUri>) -> Self {
         Self { info: None, url }
     }
 
-    /// Create an empty `AvatarEventContent`.
+    /// Create an empty `RoomAvatarEventContent`.
     ///
     /// With the `unstable-pre-spec` feature, this method takes an `MxcUri`.
+    /// See [matrix-doc#2006](https://github.com/matrix-org/matrix-doc/issues/2006).
     #[cfg(feature = "unstable-pre-spec")]
     pub fn new() -> Self {
         Self::default()
@@ -80,16 +84,14 @@ pub struct ImageInfo {
 
     /// The URL to the thumbnail of the image.
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub thumbnail_url: Option<MxcUri>,
+    pub thumbnail_url: Option<Box<MxcUri>>,
 
     /// The [BlurHash](https://blurha.sh) for this image.
     ///
     /// This uses the unstable prefix in
     /// [MSC2448](https://github.com/matrix-org/matrix-doc/pull/2448).
-    #[cfg(feature = "unstable-pre-spec")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
-    #[serde(rename = "xyz.amorgan.blurhash")]
-    #[serde(skip_serializing_if = "Option::is_none")]
+    #[cfg(feature = "unstable-msc2448")]
+    #[serde(rename = "xyz.amorgan.blurhash", skip_serializing_if = "Option::is_none")]
     pub blurhash: Option<String>,
 }
 
