@@ -1,88 +1,80 @@
-//! Types for the *m.room.encrypted* event.
+//! Types for the [`m.room.encrypted`] event.
+//!
+//! [`m.room.encrypted`]: https://spec.matrix.org/v1.2/client-server-api/#mroomencrypted
 
 use std::collections::BTreeMap;
 
 use js_int::UInt;
 use ruma_events_macros::EventContent;
-use ruma_identifiers::DeviceIdBox;
-#[cfg(feature = "unstable-pre-spec")]
-use ruma_identifiers::EventId;
+use ruma_identifiers::{DeviceId, EventId};
 use serde::{Deserialize, Serialize};
 
-#[cfg(feature = "unstable-pre-spec")]
-use crate::{key::verification, reaction};
-use crate::{
-    room::message::{self, InReplyTo},
-    MessageEvent,
-};
+use crate::room::message::InReplyTo;
 
 mod relation_serde;
 
-/// An event that has been encrypted.
-pub type EncryptedEvent = MessageEvent<EncryptedEventContent>;
-
-/// The content payload for `EncryptedEvent`.
+/// The content of an `m.room.encrypted` event.
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[ruma_event(type = "m.room.encrypted", kind = Message, kind = ToDevice)]
-pub struct EncryptedEventContent {
+pub struct RoomEncryptedEventContent {
     /// Algorithm-specific fields.
     #[serde(flatten)]
     pub scheme: EncryptedEventScheme,
 
     /// Information about related messages for [rich replies].
     ///
-    /// [rich replies]: https://matrix.org/docs/spec/client_server/r0.6.1#rich-replies
+    /// [rich replies]: https://spec.matrix.org/v1.2/client-server-api/#rich-replies
     #[serde(flatten, skip_serializing_if = "Option::is_none")]
     pub relates_to: Option<Relation>,
 }
 
-impl EncryptedEventContent {
-    /// Creates a new `EncryptedEventContent` with the given scheme and relation.
+impl RoomEncryptedEventContent {
+    /// Creates a new `RoomEncryptedEventContent` with the given scheme and relation.
     pub fn new(scheme: EncryptedEventScheme, relates_to: Option<Relation>) -> Self {
         Self { scheme, relates_to }
     }
 }
 
-impl From<EncryptedEventScheme> for EncryptedEventContent {
+impl From<EncryptedEventScheme> for RoomEncryptedEventContent {
     fn from(scheme: EncryptedEventScheme) -> Self {
         Self { scheme, relates_to: None }
     }
 }
 
-/// The to-device content payload for `m.encrypted` events.
+/// The to-device content of an `m.room.encrypted` event.
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[ruma_event(type = "m.room.encrypted", kind = ToDevice)]
-pub struct EncryptedToDeviceEventContent {
+pub struct ToDeviceRoomEncryptedEventContent {
     /// Algorithm-specific fields.
     #[serde(flatten)]
     pub scheme: EncryptedEventScheme,
 }
 
-impl EncryptedToDeviceEventContent {
-    /// Creates a new `EncryptedToDeviceEventContent` with the given scheme.
+impl ToDeviceRoomEncryptedEventContent {
+    /// Creates a new `ToDeviceRoomEncryptedEventContent` with the given scheme.
     pub fn new(scheme: EncryptedEventScheme) -> Self {
         Self { scheme }
     }
 }
 
-impl From<EncryptedEventScheme> for EncryptedToDeviceEventContent {
+impl From<EncryptedEventScheme> for ToDeviceRoomEncryptedEventContent {
     fn from(scheme: EncryptedEventScheme) -> Self {
         Self { scheme }
     }
 }
 
-/// The encryption scheme for `EncryptedEventContent`.
+/// The encryption scheme for `RoomEncryptedEventContent`.
 #[derive(Clone, Debug, Deserialize, Serialize)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[serde(tag = "algorithm")]
 pub enum EncryptedEventScheme {
-    /// An event encrypted with *m.olm.v1.curve25519-aes-sha2*.
+    /// An event encrypted with `m.olm.v1.curve25519-aes-sha2`.
     #[serde(rename = "m.olm.v1.curve25519-aes-sha2")]
     OlmV1Curve25519AesSha2(OlmV1Curve25519AesSha2Content),
 
-    /// An event encrypted with *m.megolm.v1.aes-sha2*.
+    /// An event encrypted with `m.megolm.v1.aes-sha2`.
     #[serde(rename = "m.megolm.v1.aes-sha2")]
     MegolmV1AesSha2(MegolmV1AesSha2Content),
 }
@@ -101,18 +93,14 @@ pub enum Relation {
     },
 
     /// An event that replaces another event.
-    #[cfg(feature = "unstable-pre-spec")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
+    #[cfg(feature = "unstable-msc2676")]
     Replacement(Replacement),
 
     /// A reference to another event.
-    #[cfg(feature = "unstable-pre-spec")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
     Reference(Reference),
 
     /// An annotation to an event.
-    #[cfg(feature = "unstable-pre-spec")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
+    #[cfg(feature = "unstable-msc2677")]
     Annotation(Annotation),
 
     #[doc(hidden)]
@@ -121,57 +109,53 @@ pub enum Relation {
 
 /// The event this relation belongs to replaces another event.
 ///
-/// In contrast to [`message::Replacement`], this struct doesn't store the new content, since that
-/// is part of the encrypted payload for `m.encrypted` events.
+/// In contrast to [`message::Replacement`](crate::room::message::Replacement), this struct doesn't
+/// store the new content, since that is part of the encrypted content of an `m.room.encrypted`
+/// events.
 #[derive(Clone, Debug, Deserialize, Serialize)]
-#[cfg(feature = "unstable-pre-spec")]
-#[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
+#[cfg(feature = "unstable-msc2676")]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 pub struct Replacement {
     /// The ID of the event being replacing.
-    pub event_id: EventId,
+    pub event_id: Box<EventId>,
 }
 
 /// A reference to another event.
 #[derive(Clone, Debug, Deserialize, Serialize)]
-#[cfg(feature = "unstable-pre-spec")]
-#[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 pub struct Reference {
     /// The event we are referencing.
-    pub event_id: EventId,
+    pub event_id: Box<EventId>,
 }
 
-#[cfg(feature = "unstable-pre-spec")]
 impl Reference {
     /// Creates a new `Reference` with the given event ID.
-    pub fn new(event_id: EventId) -> Self {
+    pub fn new(event_id: Box<EventId>) -> Self {
         Self { event_id }
     }
 }
 
 /// An annotation for an event.
 #[derive(Clone, Debug, Deserialize, Serialize)]
-#[cfg(feature = "unstable-pre-spec")]
-#[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
+#[cfg(feature = "unstable-msc2677")]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 pub struct Annotation {
     /// The event that is being annotated.
-    pub event_id: EventId,
+    pub event_id: Box<EventId>,
 
     /// The annotation.
     pub key: String,
 }
 
-#[cfg(feature = "unstable-pre-spec")]
+#[cfg(feature = "unstable-msc2677")]
 impl Annotation {
     /// Creates a new `Annotation` with the given event ID and key.
-    pub fn new(event_id: EventId, key: String) -> Self {
+    pub fn new(event_id: Box<EventId>, key: String) -> Self {
         Self { event_id, key }
     }
 }
 
-/// The payload for `EncryptedEvent` using the *m.olm.v1.curve25519-aes-sha2* algorithm.
+/// The content of an `m.room.encrypted` event using the `m.olm.v1.curve25519-aes-sha2` algorithm.
 #[derive(Clone, Debug, Serialize, Deserialize)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 pub struct OlmV1Curve25519AesSha2Content {
@@ -191,7 +175,7 @@ impl OlmV1Curve25519AesSha2Content {
 
 /// Ciphertext information holding the ciphertext and message type.
 ///
-/// Used for messages encrypted with the *m.olm.v1.curve25519-aes-sha2* algorithm.
+/// Used for messages encrypted with the `m.olm.v1.curve25519-aes-sha2` algorithm.
 #[derive(Clone, Debug, Deserialize, Serialize)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 pub struct CiphertextInfo {
@@ -210,7 +194,7 @@ impl CiphertextInfo {
     }
 }
 
-/// The payload for `EncryptedEvent` using the *m.megolm.v1.aes-sha2* algorithm.
+/// The content of an `m.room.encrypted` event using the `m.megolm.v1.aes-sha2` algorithm.
 ///
 /// To create an instance of this type, first create a `MegolmV1AesSha2ContentInit` and convert it
 /// via `MegolmV1AesSha2Content::from` / `.into()`.
@@ -224,7 +208,7 @@ pub struct MegolmV1AesSha2Content {
     pub sender_key: String,
 
     /// The ID of the sending device.
-    pub device_id: DeviceIdBox,
+    pub device_id: Box<DeviceId>,
 
     /// The ID of the session used to encrypt the message.
     pub session_id: String,
@@ -244,7 +228,7 @@ pub struct MegolmV1AesSha2ContentInit {
     pub sender_key: String,
 
     /// The ID of the sending device.
-    pub device_id: DeviceIdBox,
+    pub device_id: Box<DeviceId>,
 
     /// The ID of the session used to encrypt the message.
     pub session_id: String,
@@ -258,49 +242,21 @@ impl From<MegolmV1AesSha2ContentInit> for MegolmV1AesSha2Content {
     }
 }
 
-// FIXME: Remove on next breaking change release
-impl From<message::Relation> for Relation {
-    fn from(rel: message::Relation) -> Self {
-        match rel {
-            message::Relation::Reply { in_reply_to } => Self::Reply { in_reply_to },
-            #[cfg(feature = "unstable-pre-spec")]
-            message::Relation::Replacement(re) => {
-                Self::Replacement(Replacement { event_id: re.event_id })
-            }
-            message::Relation::_Custom => Self::_Custom,
-        }
-    }
-}
-
-#[cfg(feature = "unstable-pre-spec")]
-impl From<reaction::Relation> for Relation {
-    fn from(rel: reaction::Relation) -> Self {
-        let reaction::Relation { event_id, emoji } = rel;
-        Self::Annotation(Annotation { event_id, key: emoji })
-    }
-}
-
-#[cfg(feature = "unstable-pre-spec")]
-impl From<verification::Relation> for Relation {
-    fn from(rel: verification::Relation) -> Self {
-        let verification::Relation { event_id } = rel;
-        Self::Reference(Reference { event_id })
-    }
-}
-
 #[cfg(test)]
 mod tests {
     use matches::assert_matches;
+    use ruma_identifiers::event_id;
     use ruma_serde::Raw;
     use serde_json::{from_value as from_json_value, json, to_value as to_json_value};
 
-    use super::{EncryptedEventContent, EncryptedEventScheme, MegolmV1AesSha2Content, Relation};
+    use super::{
+        EncryptedEventScheme, MegolmV1AesSha2Content, Relation, RoomEncryptedEventContent,
+    };
     use crate::room::message::InReplyTo;
-    use ruma_identifiers::event_id;
 
     #[test]
     fn serialization() {
-        let key_verification_start_content = EncryptedEventContent {
+        let key_verification_start_content = RoomEncryptedEventContent {
             scheme: EncryptedEventScheme::MegolmV1AesSha2(MegolmV1AesSha2Content {
                 ciphertext: "ciphertext".into(),
                 sender_key: "sender_key".into(),
@@ -308,7 +264,7 @@ mod tests {
                 session_id: "session_id".into(),
             }),
             relates_to: Some(Relation::Reply {
-                in_reply_to: InReplyTo { event_id: event_id!("$h29iv0s8:example.com") },
+                in_reply_to: InReplyTo { event_id: event_id!("$h29iv0s8:example.com").to_owned() },
             }),
         };
 
@@ -343,11 +299,7 @@ mod tests {
             },
         });
 
-        let content: EncryptedEventContent =
-            from_json_value::<Raw<EncryptedEventContent>>(json_data)
-                .unwrap()
-                .deserialize()
-                .unwrap();
+        let content: RoomEncryptedEventContent = from_json_value(json_data).unwrap();
 
         assert_matches!(
             content.scheme,
@@ -381,10 +333,7 @@ mod tests {
             },
             "algorithm": "m.olm.v1.curve25519-aes-sha2"
         });
-        let content = from_json_value::<Raw<EncryptedEventContent>>(json_data)
-            .unwrap()
-            .deserialize()
-            .unwrap();
+        let content: RoomEncryptedEventContent = from_json_value(json_data).unwrap();
 
         match content.scheme {
             EncryptedEventScheme::OlmV1Curve25519AesSha2(c) => {
@@ -399,7 +348,7 @@ mod tests {
 
     #[test]
     fn deserialization_failure() {
-        assert!(from_json_value::<Raw<EncryptedEventContent>>(
+        assert!(from_json_value::<Raw<RoomEncryptedEventContent>>(
             json!({ "algorithm": "m.megolm.v1.aes-sha2" })
         )
         .unwrap()
