@@ -1,19 +1,20 @@
-//! Types for the *m.room.encryption* event.
+//! Types for the [`m.room.encryption`] event.
+//!
+//! [`m.room.encryption`]: https://spec.matrix.org/v1.2/client-server-api/#mroomencryption
 
 use js_int::UInt;
 use ruma_events_macros::EventContent;
 use serde::{Deserialize, Serialize};
 
-use crate::{EventEncryptionAlgorithm, StateEvent};
+use crate::EventEncryptionAlgorithm;
 
+/// The content of an `m.room.encryption` event.
+///
 /// Defines how messages sent in this room should be encrypted.
-pub type EncryptionEvent = StateEvent<EncryptionEventContent>;
-
-/// The payload for `EncryptionEvent`.
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[ruma_event(type = "m.room.encryption", kind = State)]
-pub struct EncryptionEventContent {
+pub struct RoomEncryptionEventContent {
     /// The encryption algorithm to be used to encrypt messages sent in this room.
     ///
     /// Must be `m.megolm.v1.aes-sha2`.
@@ -32,8 +33,8 @@ pub struct EncryptionEventContent {
     pub rotation_period_msgs: Option<UInt>,
 }
 
-impl EncryptionEventContent {
-    /// Creates a new `EncryptionEventContent` with the given algorithm.
+impl RoomEncryptionEventContent {
+    /// Creates a new `RoomEncryptionEventContent` with the given algorithm.
     pub fn new(algorithm: EventEncryptionAlgorithm) -> Self {
         Self { algorithm, rotation_period_ms: None, rotation_period_msgs: None }
     }
