@@ -1,27 +1,28 @@
-//! Types for the *m.room.history_visibility* event.
+//! Types for the [`m.room.history_visibility`] event.
+//!
+//! [`m.room.history_visibility`]: https://spec.matrix.org/v1.2/client-server-api/#mroomhistory_visibility
 
 use ruma_events_macros::EventContent;
 use ruma_serde::StringEnum;
 use serde::{Deserialize, Serialize};
 
-use crate::StateEvent;
+use crate::PrivOwnedStr;
 
-/// This event controls whether a member of a room can see the events that happened in a room
-/// from before they joined.
-pub type HistoryVisibilityEvent = StateEvent<HistoryVisibilityEventContent>;
-
-/// The payload for `HistoryVisibilityEvent`.
+/// The content of an `m.room.history_visibility` event.
+///
+/// This event controls whether a member of a room can see the events that happened in a room from
+/// before they joined.
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[ruma_event(type = "m.room.history_visibility", kind = State)]
-pub struct HistoryVisibilityEventContent {
+pub struct RoomHistoryVisibilityEventContent {
     /// Who can see the room history.
     #[ruma_event(skip_redaction)]
     pub history_visibility: HistoryVisibility,
 }
 
-impl HistoryVisibilityEventContent {
-    /// Creates a new `HistoryVisibilityEventContent` with the given policy.
+impl RoomHistoryVisibilityEventContent {
+    /// Creates a new `RoomHistoryVisibilityEventContent` with the given policy.
     pub fn new(history_visibility: HistoryVisibility) -> Self {
         Self { history_visibility }
     }
@@ -36,25 +37,30 @@ impl HistoryVisibilityEventContent {
 #[non_exhaustive]
 pub enum HistoryVisibility {
     /// Previous events are accessible to newly joined members from the point they were invited
-    /// onwards. Events stop being accessible when the member's state changes to something other
-    /// than *invite* or *join*.
+    /// onwards.
+    ///
+    /// Events stop being accessible when the member's state changes to something other than
+    /// *invite* or *join*.
     Invited,
 
     /// Previous events are accessible to newly joined members from the point they joined the room
-    /// onwards. Events stop being accessible when the member's state changes to something other
-    /// than *join*.
+    /// onwards.
+    /// Events stop being accessible when the member's state changes to something other than
+    /// *join*.
     Joined,
 
-    /// Previous events are always accessible to newly joined members. All events in the room are
-    /// accessible, even those sent when the member was not a part of the room.
+    /// Previous events are always accessible to newly joined members.
+    ///
+    /// All events in the room are accessible, even those sent when the member was not a part of
+    /// the room.
     Shared,
 
-    /// All events while this is the `HistoryVisibility` value may be shared by any
-    /// participating homeserver with anyone, regardless of whether they have ever joined the room.
+    /// All events while this is the `HistoryVisibility` value may be shared by any participating
+    /// homeserver with anyone, regardless of whether they have ever joined the room.
     WorldReadable,
 
     #[doc(hidden)]
-    _Custom(String),
+    _Custom(PrivOwnedStr),
 }
 
 impl HistoryVisibility {
