@@ -1,37 +1,35 @@
-//! Types for the *m.room.message* event.
+//! Types for the [`m.room.message`] event.
+//!
+//! [`m.room.message`]: https://spec.matrix.org/v1.2/client-server-api/#mroommessage
 
-use std::borrow::Cow;
+use std::{borrow::Cow, fmt};
 
-use indoc::formatdoc;
 use js_int::UInt;
 use ruma_events_macros::EventContent;
-#[cfg(feature = "unstable-pre-spec")]
-use ruma_identifiers::{DeviceIdBox, UserId};
-use ruma_identifiers::{EventId, MxcUri};
-use ruma_serde::StringEnum;
+use ruma_identifiers::{DeviceId, EventId, MxcUri, UserId};
+use ruma_serde::{JsonObject, StringEnum};
 use serde::{de::DeserializeOwned, Deserialize, Serialize};
 use serde_json::Value as JsonValue;
 
 use super::{EncryptedFile, ImageInfo, ThumbnailInfo};
-#[cfg(feature = "unstable-pre-spec")]
-use crate::key::verification::VerificationMethod;
+use crate::{key::verification::VerificationMethod, PrivOwnedStr};
 
 mod content_serde;
 pub mod feedback;
 mod relation_serde;
+mod reply;
 
-type JsonObject = serde_json::Map<String, JsonValue>;
+pub use reply::ReplyBaseEvent;
 
+/// The content of an `m.room.message` event.
+///
 /// This event is used when sending messages in a room.
 ///
 /// Messages are not limited to be text.
-pub type MessageEvent = crate::MessageEvent<MessageEventContent>;
-
-/// The payload for `MessageEvent`.
 #[derive(Clone, Debug, Serialize, EventContent)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[ruma_event(type = "m.room.message", kind = Message)]
-pub struct MessageEventContent {
+pub struct RoomMessageEventContent {
     /// A key which identifies the type of message being sent.
     ///
     /// This also holds the specific content of each message.
@@ -40,13 +38,13 @@ pub struct MessageEventContent {
 
     /// Information about related messages for [rich replies].
     ///
-    /// [rich replies]: https://matrix.org/docs/spec/client_server/r0.6.1#rich-replies
+    /// [rich replies]: https://spec.matrix.org/v1.2/client-server-api/#rich-replies
     #[serde(flatten, skip_serializing_if = "Option::is_none")]
     pub relates_to: Option<Relation>,
 }
 
-impl MessageEventContent {
-    /// Create a `MessageEventContent` with the given `MessageType`.
+impl RoomMessageEventContent {
+    /// Create a `RoomMessageEventContent` with the given `MessageType`.
     pub fn new(msgtype: MessageType) -> Self {
         Self { msgtype, relates_to: None }
     }
@@ -61,6 +59,12 @@ impl MessageEventContent {
         Self::new(MessageType::Text(TextMessageEventContent::html(body, html_body)))
     }
 
+    /// A constructor to create a markdown message.
+    #[cfg(feature = "markdown")]
+    pub fn text_markdown(body: impl AsRef<str> + Into<String>) -> Self {
+        Self::new(MessageType::Text(TextMessageEventContent::markdown(body)))
+    }
+
     /// A constructor to create a plain text notice.
     pub fn notice_plain(body: impl Into<String>) -> Self {
         Self::new(MessageType::Notice(NoticeMessageEventContent::plain(body)))
@@ -71,31 +75,45 @@ impl MessageEventContent {
         Self::new(MessageType::Notice(NoticeMessageEventContent::html(body, html_body)))
     }
 
-    /// Creates a plain text reply to a message.
-    pub fn text_reply_plain(reply: impl Into<String>, original_message: &MessageEvent) -> Self {
-        let quoted = get_plain_quote_fallback(original_message);
+    /// A constructor to create a markdown notice.
+    #[cfg(feature = "markdown")]
+    pub fn notice_markdown(body: impl AsRef<str> + Into<String>) -> Self {
+        Self::new(MessageType::Notice(NoticeMessageEventContent::markdown(body)))
+    }
 
-        let body = format!("{}\n\n{}", quoted, reply.into());
+    /// Creates a plain text reply to a message.
+    pub fn text_reply_plain(
+        reply: impl fmt::Display,
+        original_message: &impl ReplyBaseEvent,
+    ) -> Self {
+        let quoted = reply::get_plain_quote_fallback(original_message);
+
+        let body = format!("{}\n\n{}", quoted, reply);
 
         Self {
             relates_to: Some(Relation::Reply {
-                in_reply_to: InReplyTo { event_id: original_message.event_id.clone() },
+                in_reply_to: InReplyTo { event_id: original_message.event_id().to_owned() },
             }),
             ..Self::text_plain(body)
         }
     }
 
     /// Creates a html text reply to a message.
+    ///
+    /// Different from `text_reply_plain`, this constructor requires specifically a
+    /// [`RoomMessageEvent`] since it creates a permalink to the previous message, for which the
+    /// room ID is required. If you want to reply to a [`SyncRoomMessageEvent`], you have to convert
+    /// it first by calling [`.into_full_event()`][crate::SyncMessageEvent::into_full_event].
     pub fn text_reply_html(
-        reply: impl Into<String>,
-        html_reply: impl Into<String>,
-        original_message: &MessageEvent,
+        reply: impl fmt::Display,
+        html_reply: impl fmt::Display,
+        original_message: &RoomMessageEvent,
     ) -> Self {
-        let quoted = get_plain_quote_fallback(original_message);
-        let quoted_html = get_html_quote_fallback(original_message);
+        let quoted = reply::get_plain_quote_fallback(original_message);
+        let quoted_html = reply::get_html_quote_fallback(original_message);
 
-        let body = format!("{}\n\n{}", quoted, reply.into());
-        let html_body = format!("{}\n\n{}", quoted_html, html_reply.into());
+        let body = format!("{}\n\n{}", quoted, reply);
+        let html_body = format!("{}\n\n{}", quoted_html, html_reply);
 
         Self {
             relates_to: Some(Relation::Reply {
@@ -106,29 +124,37 @@ impl MessageEventContent {
     }
 
     /// Creates a plain text notice reply to a message.
-    pub fn notice_reply_plain(reply: impl Into<String>, original_message: &MessageEvent) -> Self {
-        let quoted = get_plain_quote_fallback(original_message);
+    pub fn notice_reply_plain(
+        reply: impl fmt::Display,
+        original_message: &impl ReplyBaseEvent,
+    ) -> Self {
+        let quoted = reply::get_plain_quote_fallback(original_message);
 
-        let body = format!("{}\n\n{}", quoted, reply.into());
+        let body = format!("{}\n\n{}", quoted, reply);
         Self {
             relates_to: Some(Relation::Reply {
-                in_reply_to: InReplyTo { event_id: original_message.event_id.clone() },
+                in_reply_to: InReplyTo { event_id: original_message.event_id().to_owned() },
             }),
             ..Self::notice_plain(body)
         }
     }
 
     /// Creates a html text notice reply to a message.
+    ///
+    /// Different from `notice_reply_plain`, this constructor requires specifically a
+    /// [`RoomMessageEvent`] since it creates a permalink to the previous message, for which the
+    /// room ID is required. If you want to reply to a [`SyncRoomMessageEvent`], you have to convert
+    /// it first by calling [`.into_full_event()`][crate::SyncMessageEvent::into_full_event].
     pub fn notice_reply_html(
-        reply: impl Into<String>,
-        html_reply: impl Into<String>,
-        original_message: &MessageEvent,
+        reply: impl fmt::Display,
+        html_reply: impl fmt::Display,
+        original_message: &RoomMessageEvent,
     ) -> Self {
-        let quoted = get_plain_quote_fallback(original_message);
-        let quoted_html = get_html_quote_fallback(original_message);
+        let quoted = reply::get_plain_quote_fallback(original_message);
+        let quoted_html = reply::get_html_quote_fallback(original_message);
 
-        let body = format!("{}\n\n{}", quoted, reply.into());
-        let html_body = format!("{}\n\n{}", quoted_html, html_reply.into());
+        let body = format!("{}\n\n{}", quoted, reply);
+        let html_body = format!("{}\n\n{}", quoted_html, html_reply);
 
         Self {
             relates_to: Some(Relation::Reply {
@@ -137,6 +163,19 @@ impl MessageEventContent {
             ..Self::notice_html(body, html_body)
         }
     }
+
+    /// Returns a reference to the `msgtype` string.
+    ///
+    /// If you want to access the message type-specific data rather than the message type itself,
+    /// use the `msgtype` *field*, not this method.
+    pub fn msgtype(&self) -> &str {
+        self.msgtype.msgtype()
+    }
+
+    /// Return a reference to the message body.
+    pub fn body(&self) -> &str {
+        self.msgtype.body()
+    }
 }
 
 /// The content that is specific to each message type variant.
@@ -172,8 +211,6 @@ pub enum MessageType {
     Video(VideoMessageEventContent),
 
     /// A request to initiate a key verification.
-    #[cfg(feature = "unstable-pre-spec")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
     VerificationRequest(KeyVerificationRequestEventContent),
 
     /// A custom message.
@@ -187,24 +224,34 @@ impl MessageType {
     /// Prefer to use the public variants of `MessageType` where possible; this constructor is meant
     /// be used for unsupported message types only and does not allow setting arbitrary data for
     /// supported ones.
-    pub fn new(msgtype: &str, data: JsonObject) -> serde_json::Result<Self> {
-        fn from_json_object<T: DeserializeOwned>(obj: JsonObject) -> serde_json::Result<T> {
+    ///
+    /// # Errors
+    ///
+    /// Returns an error if the `msgtype` is known and serialization of `data` to the corresponding
+    /// `MessageType` variant fails.
+    pub fn new(msgtype: &str, body: String, data: JsonObject) -> serde_json::Result<Self> {
+        fn deserialize_variant<T: DeserializeOwned>(
+            body: String,
+            mut obj: JsonObject,
+        ) -> serde_json::Result<T> {
+            obj.insert("body".into(), body.into());
             serde_json::from_value(JsonValue::Object(obj))
         }
 
         Ok(match msgtype {
-            "m.audio" => Self::Audio(from_json_object(data)?),
-            "m.emote" => Self::Emote(from_json_object(data)?),
-            "m.file" => Self::File(from_json_object(data)?),
-            "m.image" => Self::Image(from_json_object(data)?),
-            "m.location" => Self::Location(from_json_object(data)?),
-            "m.notice" => Self::Notice(from_json_object(data)?),
-            "m.server_notice" => Self::ServerNotice(from_json_object(data)?),
-            "m.text" => Self::Text(from_json_object(data)?),
-            "m.video" => Self::Video(from_json_object(data)?),
-            #[cfg(feature = "unstable-pre-spec")]
-            "m.key.verification.request" => Self::VerificationRequest(from_json_object(data)?),
-            _ => Self::_Custom(CustomEventContent { msgtype: msgtype.to_owned(), data }),
+            "m.audio" => Self::Audio(deserialize_variant(body, data)?),
+            "m.emote" => Self::Emote(deserialize_variant(body, data)?),
+            "m.file" => Self::File(deserialize_variant(body, data)?),
+            "m.image" => Self::Image(deserialize_variant(body, data)?),
+            "m.location" => Self::Location(deserialize_variant(body, data)?),
+            "m.notice" => Self::Notice(deserialize_variant(body, data)?),
+            "m.server_notice" => Self::ServerNotice(deserialize_variant(body, data)?),
+            "m.text" => Self::Text(deserialize_variant(body, data)?),
+            "m.video" => Self::Video(deserialize_variant(body, data)?),
+            "m.key.verification.request" => {
+                Self::VerificationRequest(deserialize_variant(body, data)?)
+            }
+            _ => Self::_Custom(CustomEventContent { msgtype: msgtype.to_owned(), body, data }),
         })
     }
 
@@ -220,20 +267,42 @@ impl MessageType {
             Self::ServerNotice(_) => "m.server_notice",
             Self::Text(_) => "m.text",
             Self::Video(_) => "m.video",
-            #[cfg(feature = "unstable-pre-spec")]
             Self::VerificationRequest(_) => "m.key.verification.request",
             Self::_Custom(c) => &c.msgtype,
         }
     }
 
+    /// Return a reference to the message body.
+    pub fn body(&self) -> &str {
+        match self {
+            MessageType::Audio(m) => &m.body,
+            MessageType::Emote(m) => &m.body,
+            MessageType::File(m) => &m.body,
+            MessageType::Image(m) => &m.body,
+            MessageType::Location(m) => &m.body,
+            MessageType::Notice(m) => &m.body,
+            MessageType::ServerNotice(m) => &m.body,
+            MessageType::Text(m) => &m.body,
+            MessageType::Video(m) => &m.body,
+            MessageType::VerificationRequest(m) => &m.body,
+            MessageType::_Custom(m) => &m.body,
+        }
+    }
+
     /// Returns the associated data.
     ///
+    /// The returned JSON object won't contain the `msgtype` and `body` fields, use
+    /// [`.msgtype()`][Self::msgtype] / [`.body()`](Self::body) to access those.
+    ///
     /// Prefer to use the public variants of `MessageType` where possible; this method is meant to
-    /// be used for unsupported message types only.
+    /// be used for custom message types only.
     pub fn data(&self) -> Cow<'_, JsonObject> {
         fn serialize<T: Serialize>(obj: &T) -> JsonObject {
             match serde_json::to_value(obj).expect("message type serialization to succeed") {
-                JsonValue::Object(obj) => obj,
+                JsonValue::Object(mut obj) => {
+                    obj.remove("body");
+                    obj
+                }
                 _ => panic!("all message types must serialize to objects"),
             }
         }
@@ -248,20 +317,19 @@ impl MessageType {
             Self::ServerNotice(d) => Cow::Owned(serialize(d)),
             Self::Text(d) => Cow::Owned(serialize(d)),
             Self::Video(d) => Cow::Owned(serialize(d)),
-            #[cfg(feature = "unstable-pre-spec")]
             Self::VerificationRequest(d) => Cow::Owned(serialize(d)),
             Self::_Custom(c) => Cow::Borrowed(&c.data),
         }
     }
 }
 
-impl From<MessageType> for MessageEventContent {
+impl From<MessageType> for RoomMessageEventContent {
     fn from(msgtype: MessageType) -> Self {
         Self::new(msgtype)
     }
 }
 
-/// Message vent relationship.
+/// Message event relationship.
 ///
 /// Currently used for replies and editing (message replacement).
 #[derive(Clone, Debug)]
@@ -275,8 +343,7 @@ pub enum Relation {
     },
 
     /// An event that replaces another event.
-    #[cfg(feature = "unstable-pre-spec")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
+    #[cfg(feature = "unstable-msc2676")]
     Replacement(Replacement),
 
     #[doc(hidden)]
@@ -288,33 +355,32 @@ pub enum Relation {
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 pub struct InReplyTo {
     /// The event being replied to.
-    pub event_id: EventId,
+    pub event_id: Box<EventId>,
 }
 
 impl InReplyTo {
     /// Creates a new `InReplyTo` with the given event ID.
-    pub fn new(event_id: EventId) -> Self {
+    pub fn new(event_id: Box<EventId>) -> Self {
         Self { event_id }
     }
 }
 
 /// The event this relation belongs to replaces another event.
 #[derive(Clone, Debug)]
-#[cfg(feature = "unstable-pre-spec")]
-#[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
+#[cfg(feature = "unstable-msc2676")]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 pub struct Replacement {
     /// The ID of the event being replacing.
-    pub event_id: EventId,
+    pub event_id: Box<EventId>,
 
     /// New content.
-    pub new_content: Box<MessageEventContent>,
+    pub new_content: Box<RoomMessageEventContent>,
 }
 
-#[cfg(feature = "unstable-pre-spec")]
+#[cfg(feature = "unstable-msc2676")]
 impl Replacement {
     /// Creates a new `Replacement` with the given event ID and new content.
-    pub fn new(event_id: EventId, new_content: Box<MessageEventContent>) -> Self {
+    pub fn new(event_id: Box<EventId>, new_content: Box<RoomMessageEventContent>) -> Self {
         Self { event_id, new_content }
     }
 }
@@ -331,7 +397,7 @@ pub struct AudioMessageEventContent {
     ///
     /// Required if the file is unencrypted.
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub url: Option<MxcUri>,
+    pub url: Option<Box<MxcUri>>,
 
     /// Information on the encrypted audio clip.
     ///
@@ -345,13 +411,14 @@ pub struct AudioMessageEventContent {
 }
 
 impl AudioMessageEventContent {
-    /// Creates a new non-encrypted `AudioMessageEventContent` with the given body, url and optional
-    /// extra info.
-    pub fn plain(body: String, url: MxcUri, info: Option<Box<AudioInfo>>) -> Self {
+    /// Creates a new non-encrypted `RoomAudioMessageEventContent` with the given body, url and
+    /// optional extra info.
+    pub fn plain(body: String, url: Box<MxcUri>, info: Option<Box<AudioInfo>>) -> Self {
         Self { body, url: Some(url), info, file: None }
     }
 
-    /// Creates a new encrypted `AudioMessageEventContent` with the given body and encrypted file.
+    /// Creates a new encrypted `RoomAudioMessageEventContent` with the given body and encrypted
+    /// file.
     pub fn encrypted(body: String, file: EncryptedFile) -> Self {
         Self { body, url: None, info: None, file: Some(Box::new(file)) }
     }
@@ -410,7 +477,6 @@ impl EmoteMessageEventContent {
     /// Returns an html emote message if some markdown formatting was detected, otherwise returns a
     /// plain-text emote.
     #[cfg(feature = "markdown")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "markdown")))]
     pub fn markdown(body: impl AsRef<str> + Into<String>) -> Self {
         Self { formatted: FormattedBody::markdown(&body), ..Self::plain(body) }
     }
@@ -432,7 +498,7 @@ pub struct FileMessageEventContent {
 
     /// The URL to the file.
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub url: Option<MxcUri>,
+    pub url: Option<Box<MxcUri>>,
 
     /// Information on the encrypted file.
     ///
@@ -446,13 +512,14 @@ pub struct FileMessageEventContent {
 }
 
 impl FileMessageEventContent {
-    /// Creates a new non-encrypted `FileMessageEventContent` with the given body, url and optional
-    /// extra info.
-    pub fn plain(body: String, url: MxcUri, info: Option<Box<FileInfo>>) -> Self {
+    /// Creates a new non-encrypted `RoomFileMessageEventContent` with the given body, url and
+    /// optional extra info.
+    pub fn plain(body: String, url: Box<MxcUri>, info: Option<Box<FileInfo>>) -> Self {
         Self { body, filename: None, url: Some(url), info, file: None }
     }
 
-    /// Creates a new encrypted `FileMessageEventContent` with the given body and encrypted file.
+    /// Creates a new encrypted `RoomFileMessageEventContent` with the given body and encrypted
+    /// file.
     pub fn encrypted(body: String, file: EncryptedFile) -> Self {
         Self { body, filename: None, url: None, info: None, file: Some(Box::new(file)) }
     }
@@ -478,7 +545,7 @@ pub struct FileInfo {
     ///
     /// Only present if the thumbnail is unencrypted.
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub thumbnail_url: Option<MxcUri>,
+    pub thumbnail_url: Option<Box<MxcUri>>,
 
     /// Information on the encrypted thumbnail file.
     ///
@@ -501,13 +568,13 @@ impl FileInfo {
 pub struct ImageMessageEventContent {
     /// A textual representation of the image.
     ///
-    /// This could be the alt text of the image, the filename of the image, or some kind of content
+    /// Could be the alt text of the image, the filename of the image, or some kind of content
     /// description for accessibility e.g. "image attachment".
     pub body: String,
 
     /// The URL to the image.
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub url: Option<MxcUri>,
+    pub url: Option<Box<MxcUri>>,
 
     /// Information on the encrypted image.
     ///
@@ -521,13 +588,14 @@ pub struct ImageMessageEventContent {
 }
 
 impl ImageMessageEventContent {
-    /// Creates a new non-encrypted `ImageMessageEventContent` with the given body, url and optional
-    /// extra info.
-    pub fn plain(body: String, url: MxcUri, info: Option<Box<ImageInfo>>) -> Self {
+    /// Creates a new non-encrypted `RoomImageMessageEventContent` with the given body, url and
+    /// optional extra info.
+    pub fn plain(body: String, url: Box<MxcUri>, info: Option<Box<ImageInfo>>) -> Self {
         Self { body, url: Some(url), info, file: None }
     }
 
-    /// Creates a new encrypted `ImageMessageEventContent` with the given body and encrypted file.
+    /// Creates a new encrypted `RoomImageMessageEventContent` with the given body and encrypted
+    /// file.
     pub fn encrypted(body: String, file: EncryptedFile) -> Self {
         Self { body, url: None, info: None, file: Some(Box::new(file)) }
     }
@@ -551,7 +619,7 @@ pub struct LocationMessageEventContent {
 }
 
 impl LocationMessageEventContent {
-    /// Creates a new `LocationMessageEventContent` with the given body and geo URI.
+    /// Creates a new `RoomLocationMessageEventContent` with the given body and geo URI.
     pub fn new(body: String, geo_uri: String) -> Self {
         Self { body, geo_uri, info: None }
     }
@@ -565,7 +633,7 @@ pub struct LocationInfo {
     ///
     /// Only present if the thumbnail is unencrypted.
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub thumbnail_url: Option<MxcUri>,
+    pub thumbnail_url: Option<Box<MxcUri>>,
 
     /// Information on an encrypted thumbnail of the location being represented.
     ///
@@ -614,7 +682,6 @@ impl NoticeMessageEventContent {
     /// Returns an html notice if some markdown formatting was detected, otherwise returns a plain
     /// text notice.
     #[cfg(feature = "markdown")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "markdown")))]
     pub fn markdown(body: impl AsRef<str> + Into<String>) -> Self {
         Self { formatted: FormattedBody::markdown(&body), ..Self::plain(body) }
     }
@@ -645,7 +712,7 @@ pub struct ServerNoticeMessageEventContent {
 }
 
 impl ServerNoticeMessageEventContent {
-    /// Creates a new `ServerNoticeMessageEventContent` with the given body and notice type.
+    /// Creates a new `RoomServerNoticeMessageEventContent` with the given body and notice type.
     pub fn new(body: String, server_notice_type: ServerNoticeType) -> Self {
         Self { body, server_notice_type, admin_contact: None, limit_type: None }
     }
@@ -663,7 +730,7 @@ pub enum ServerNoticeType {
     UsageLimitReached,
 
     #[doc(hidden)]
-    _Custom(String),
+    _Custom(PrivOwnedStr),
 }
 
 impl ServerNoticeType {
@@ -688,7 +755,7 @@ pub enum LimitType {
     MonthlyActiveUser,
 
     #[doc(hidden)]
-    _Custom(String),
+    _Custom(PrivOwnedStr),
 }
 
 impl LimitType {
@@ -710,7 +777,7 @@ pub enum MessageFormat {
     Html,
 
     #[doc(hidden)]
-    _Custom(String),
+    _Custom(PrivOwnedStr),
 }
 
 impl MessageFormat {
@@ -743,7 +810,6 @@ impl FormattedBody {
     ///
     /// Returns `None` if no markdown formatting was found.
     #[cfg(feature = "markdown")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "markdown")))]
     pub fn markdown(body: impl AsRef<str>) -> Option<Self> {
         let body = body.as_ref();
         let mut html_body = String::new();
@@ -783,7 +849,6 @@ impl TextMessageEventContent {
     /// Returns an html message if some markdown formatting was detected, otherwise returns a plain
     /// text message.
     #[cfg(feature = "markdown")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "markdown")))]
     pub fn markdown(body: impl AsRef<str> + Into<String>) -> Self {
         Self { formatted: FormattedBody::markdown(&body), ..Self::plain(body) }
     }
@@ -800,7 +865,7 @@ pub struct VideoMessageEventContent {
 
     /// The URL to the video clip.
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub url: Option<MxcUri>,
+    pub url: Option<Box<MxcUri>>,
 
     /// Information on the encrypted video clip.
     ///
@@ -814,13 +879,14 @@ pub struct VideoMessageEventContent {
 }
 
 impl VideoMessageEventContent {
-    /// Creates a new non-encrypted `VideoMessageEventContent` with the given body, url and optional
-    /// extra info.
-    pub fn plain(body: String, url: MxcUri, info: Option<Box<VideoInfo>>) -> Self {
+    /// Creates a new non-encrypted `RoomVideoMessageEventContent` with the given body, url and
+    /// optional extra info.
+    pub fn plain(body: String, url: Box<MxcUri>, info: Option<Box<VideoInfo>>) -> Self {
         Self { body, url: Some(url), info, file: None }
     }
 
-    /// Creates a new encrypted `VideoMessageEventContent` with the given body and encrypted file.
+    /// Creates a new encrypted `RoomVideoMessageEventContent` with the given body and encrypted
+    /// file.
     pub fn encrypted(body: String, file: EncryptedFile) -> Self {
         Self { body, url: None, info: None, file: Some(Box::new(file)) }
     }
@@ -835,13 +901,11 @@ pub struct VideoInfo {
     pub duration: Option<UInt>,
 
     /// The height of the video in pixels.
-    #[serde(rename = "h")]
-    #[serde(skip_serializing_if = "Option::is_none")]
+    #[serde(rename = "h", skip_serializing_if = "Option::is_none")]
     pub height: Option<UInt>,
 
     /// The width of the video in pixels.
-    #[serde(rename = "w")]
-    #[serde(skip_serializing_if = "Option::is_none")]
+    #[serde(rename = "w", skip_serializing_if = "Option::is_none")]
     pub width: Option<UInt>,
 
     /// The mimetype of the video, e.g. "video/mp4".
@@ -860,7 +924,7 @@ pub struct VideoInfo {
     ///
     /// Only present if the thumbnail is unencrypted.
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub thumbnail_url: Option<MxcUri>,
+    pub thumbnail_url: Option<Box<MxcUri>>,
 
     /// Information on the encrypted thumbnail file.
     ///
@@ -872,10 +936,8 @@ pub struct VideoInfo {
     ///
     /// This uses the unstable prefix in
     /// [MSC2448](https://github.com/matrix-org/matrix-doc/pull/2448).
-    #[cfg(feature = "unstable-pre-spec")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
-    #[serde(rename = "xyz.amorgan.blurhash")]
-    #[serde(skip_serializing_if = "Option::is_none")]
+    #[cfg(feature = "unstable-msc2448")]
+    #[serde(rename = "xyz.amorgan.blurhash", skip_serializing_if = "Option::is_none")]
     pub blurhash: Option<String>,
 }
 
@@ -888,8 +950,6 @@ impl VideoInfo {
 
 /// The payload for a key verification request message.
 #[derive(Clone, Debug, Deserialize, Serialize)]
-#[cfg(feature = "unstable-pre-spec")]
-#[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[serde(tag = "msgtype", rename = "m.key.verification.request")]
 pub struct KeyVerificationRequestEventContent {
@@ -901,25 +961,24 @@ pub struct KeyVerificationRequestEventContent {
     pub methods: Vec<VerificationMethod>,
 
     /// The device ID which is initiating the request.
-    pub from_device: DeviceIdBox,
+    pub from_device: Box<DeviceId>,
 
     /// The user ID which should receive the request.
     ///
     /// Users should only respond to verification requests if they are named in this field. Users
     /// who are not named in this field and who did not send this event should ignore all other
     /// events that have a `m.reference` relationship with this event.
-    pub to: UserId,
+    pub to: Box<UserId>,
 }
 
-#[cfg(feature = "unstable-pre-spec")]
 impl KeyVerificationRequestEventContent {
-    /// Creates a new `KeyVerificationRequestEventContent` with the given body, method, device and
-    /// user ID.
+    /// Creates a new `RoomKeyVerificationRequestEventContent` with the given body, method, device
+    /// and user ID.
     pub fn new(
         body: String,
         methods: Vec<VerificationMethod>,
-        from_device: DeviceIdBox,
-        to: UserId,
+        from_device: Box<DeviceId>,
+        to: Box<UserId>,
     ) -> Self {
         Self { body, methods, from_device, to }
     }
@@ -929,272 +988,24 @@ impl KeyVerificationRequestEventContent {
 #[doc(hidden)]
 #[derive(Clone, Debug, Deserialize, Serialize)]
 pub struct CustomEventContent {
-    /// A custom msgtype
+    /// A custom msgtype.
     msgtype: String,
 
-    /// Remaining event content
+    /// The message body.
+    body: String,
+
+    /// Remaining event content.
     #[serde(flatten)]
     data: JsonObject,
 }
 
-fn get_plain_quote_fallback(original_message: &MessageEvent) -> String {
-    match &original_message.content.msgtype {
-        MessageType::Audio(_) => {
-            format!("> <{:?}> sent an audio file.", original_message.sender)
-        }
-        MessageType::Emote(content) => {
-            format!("> * <{:?}> {}", original_message.sender, content.body)
-        }
-        MessageType::File(_) => {
-            format!("> <{:?}> sent a file.", original_message.sender)
-        }
-        MessageType::Image(_) => {
-            format!("> <{:?}> sent an image.", original_message.sender)
-        }
-        MessageType::Location(content) => {
-            format!("> <{:?}> {}", original_message.sender, content.body)
-        }
-        MessageType::Notice(content) => {
-            format!("> <{:?}> {}", original_message.sender, content.body)
-        }
-        MessageType::ServerNotice(content) => {
-            format!("> <{:?}> {}", original_message.sender, content.body)
-        }
-        MessageType::Text(content) => {
-            format!("> <{:?}> {}", original_message.sender, content.body)
-        }
-        MessageType::Video(_) => {
-            format!("> <{:?}> sent a video.", original_message.sender)
-        }
-        MessageType::_Custom(content) => {
-            format!(
-                "> <{:?}> {}",
-                original_message.sender,
-                content.data["body"].as_str().unwrap_or(""),
-            )
-        }
-        #[cfg(feature = "unstable-pre-spec")]
-        MessageType::VerificationRequest(content) => {
-            format!("> <{:?}> {}", original_message.sender, content.body)
-        }
-    }
-}
-
-#[allow(clippy::nonstandard_macro_braces)]
-fn get_html_quote_fallback(original_message: &MessageEvent) -> String {
-    match &original_message.content.msgtype {
-        MessageType::Audio(_) => {
-            formatdoc!(
-                "
-                <mx-reply>
-                    <blockquote>
-                        <a href=\"https://matrix.to/#/{room_id}/{event_id}\">In reply to</a>
-                        <a href=\"https://matrix.to/#/{sender}\">{sender}</a>
-                        <br />
-                        sent an audio file.
-                    </blockquote>
-                </mx-reply>
-                ",
-                room_id = original_message.room_id,
-                event_id = original_message.event_id,
-                sender = original_message.sender,
-            )
-        }
-        MessageType::Emote(content) => {
-            formatdoc!(
-                "
-                <mx-reply>
-                    <blockquote>
-                        <a href=\"https://matrix.to/#/{room_id}/{event_id}\">In reply to</a>
-                        * <a href=\"https://matrix.to/#/{sender}\">{sender}</a>
-                        <br />
-                        {body}
-                    </blockquote>
-                </mx-reply>
-                ",
-                room_id = original_message.room_id,
-                event_id = original_message.event_id,
-                sender = original_message.sender,
-                body = formatted_or_plain_body(&content.formatted, &content.body),
-            )
-        }
-        MessageType::File(_) => {
-            formatdoc!(
-                "
-                <mx-reply>
-                    <blockquote>
-                        <a href=\"https://matrix.to/#/{room_id}/{event_id}\">In reply to</a>
-                        <a href=\"https://matrix.to/#/{sender}\">{sender}</a>
-                        <br />
-                        sent a file.
-                    </blockquote>
-                </mx-reply>
-                ",
-                room_id = original_message.room_id,
-                event_id = original_message.event_id,
-                sender = original_message.sender,
-            )
-        }
-        MessageType::Image(_) => {
-            formatdoc!(
-                "
-                <mx-reply>
-                    <blockquote>
-                        <a href=\"https://matrix.to/#/{room_id}/{event_id}\">In reply to</a>
-                        <a href=\"https://matrix.to/#/{sender}\">{sender}</a>
-                        <br />
-                        sent an image.
-                    </blockquote>
-                </mx-reply>
-                ",
-                room_id = original_message.room_id,
-                event_id = original_message.event_id,
-                sender = original_message.sender,
-            )
-        }
-        MessageType::Location(_) => {
-            formatdoc!(
-                "
-                <mx-reply>
-                    <blockquote>
-                        <a href=\"https://matrix.to/#/{room_id}/{event_id}\">In reply to</a>
-                        <a href=\"https://matrix.to/#/{sender}\">{sender}</a>
-                        <br />
-                        sent a location.
-                    </blockquote>
-                </mx-reply>
-                ",
-                room_id = original_message.room_id,
-                event_id = original_message.event_id,
-                sender = original_message.sender,
-            )
-        }
-        MessageType::Notice(content) => {
-            formatdoc!(
-                "
-                <mx-reply>
-                    <blockquote>
-                        <a href=\"https://matrix.to/#/{room_id}/{event_id}\">In reply to</a>
-                        <a href=\"https://matrix.to/#/{sender}\">{sender}</a>
-                        <br />
-                        {body}
-                    </blockquote>
-                </mx-reply>
-                ",
-                room_id = original_message.room_id,
-                event_id = original_message.event_id,
-                sender = original_message.sender,
-                body = formatted_or_plain_body(&content.formatted, &content.body),
-            )
-        }
-        MessageType::ServerNotice(content) => {
-            formatdoc!(
-                "
-                <mx-reply>
-                    <blockquote>
-                        <a href=\"https://matrix.to/#/{room_id}/{event_id}\">In reply to</a>
-                        <a href=\"https://matrix.to/#/{sender}\">{sender}</a>
-                        <br />
-                        {body}
-                    </blockquote>
-                </mx-reply>
-                ",
-                room_id = original_message.room_id,
-                event_id = original_message.event_id,
-                sender = original_message.sender,
-                body = content.body,
-            )
-        }
-        MessageType::Text(content) => {
-            formatdoc!(
-                "
-                <mx-reply>
-                    <blockquote>
-                        <a href=\"https://matrix.to/#/{room_id}/{event_id}\">In reply to</a>
-                        <a href=\"https://matrix.to/#/{sender}\">{sender}</a>
-                        <br />
-                        {body}
-                    </blockquote>
-                </mx-reply>
-                ",
-                room_id = original_message.room_id,
-                event_id = original_message.event_id,
-                sender = original_message.sender,
-                body = formatted_or_plain_body(&content.formatted, &content.body),
-            )
-        }
-        MessageType::Video(_) => {
-            formatdoc!(
-                "
-                <mx-reply>
-                    <blockquote>
-                        <a href=\"https://matrix.to/#/{room_id}/{event_id}\">In reply to</a>
-                        <a href=\"https://matrix.to/#/{sender}\">{sender}</a>
-                        <br />
-                        sent a video.
-                    </blockquote>
-                </mx-reply>
-                ",
-                room_id = original_message.room_id,
-                event_id = original_message.event_id,
-                sender = original_message.sender,
-            )
-        }
-        MessageType::_Custom(content) => {
-            formatdoc!(
-                "
-                <mx-reply>
-                    <blockquote>
-                        <a href=\"https://matrix.to/#/{room_id}/{event_id}\">In reply to</a>
-                        <a href=\"https://matrix.to/#/{sender}\">{sender}</a>
-                        <br />
-                        {body}
-                    </blockquote>
-                </mx-reply>
-                ",
-                room_id = original_message.room_id,
-                event_id = original_message.event_id,
-                sender = original_message.sender,
-                body = content.data["body"].as_str().unwrap_or(""),
-            )
-        }
-        #[cfg(feature = "unstable-pre-spec")]
-        MessageType::VerificationRequest(content) => {
-            formatdoc!(
-                "
-                <mx-reply>
-                    <blockquote>
-                        <a href=\"https://matrix.to/#/{server_name}/{event_id}\">In reply to</a>
-                        <a href=\"https://matrix.to/#/{sender}\">{sender}</a>
-                        <br />
-                        {body}
-                    </blockquote>
-                </mx-reply>
-                ",
-                server_name = original_message.room_id,
-                event_id = original_message.event_id,
-                sender = original_message.sender,
-                body = content.body,
-            )
-        }
-    }
-}
-
-fn formatted_or_plain_body<'a>(formatted: &'a Option<FormattedBody>, body: &'a str) -> &'a str {
-    if let Some(formatted_body) = formatted {
-        &formatted_body.body
-    } else {
-        body
-    }
-}
-
 #[cfg(test)]
 mod tests {
     use matches::assert_matches;
     use ruma_identifiers::event_id;
     use serde_json::{from_value as from_json_value, json};
 
-    use super::{InReplyTo, MessageEventContent, MessageType, Relation};
+    use super::{InReplyTo, MessageType, Relation, RoomMessageEventContent};
 
     #[test]
     fn deserialize_reply() {
@@ -1211,8 +1022,8 @@ mod tests {
         });
 
         assert_matches!(
-            from_json_value::<MessageEventContent>(json).unwrap(),
-            MessageEventContent {
+            from_json_value::<RoomMessageEventContent>(json).unwrap(),
+            RoomMessageEventContent {
                 msgtype: MessageType::Text(_),
                 relates_to: Some(Relation::Reply { in_reply_to: InReplyTo { event_id } }),
             } if event_id == ev_id
