@@ -1,15 +1,19 @@
-//! Types for the *m.room_key_request* event.
+//! Types for the [`m.room_key_request`] event.
+//!
+//! [`m.room_key_request`]: https://spec.matrix.org/v1.2/client-server-api/#mroom_key_request
 
 use ruma_events_macros::EventContent;
-use ruma_identifiers::{DeviceIdBox, EventEncryptionAlgorithm, RoomId};
+use ruma_identifiers::{DeviceId, EventEncryptionAlgorithm, RoomId, TransactionId};
 use ruma_serde::StringEnum;
 use serde::{Deserialize, Serialize};
 
-/// The payload for `RoomKeyRequestEvent`.
+use crate::PrivOwnedStr;
+
+/// The content of an `m.room_key_request` event.
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[ruma_event(type = "m.room_key_request", kind = ToDevice)]
-pub struct RoomKeyRequestToDeviceEventContent {
+pub struct ToDeviceRoomKeyRequestEventContent {
     /// Whether this is a new key request or a cancellation of a previous request.
     pub action: Action,
 
@@ -19,23 +23,23 @@ pub struct RoomKeyRequestToDeviceEventContent {
     pub body: Option<RequestedKeyInfo>,
 
     /// ID of the device requesting the key.
-    pub requesting_device_id: DeviceIdBox,
+    pub requesting_device_id: Box<DeviceId>,
 
     /// A random string uniquely identifying the request for a key.
     ///
     /// If the key is requested multiple times, it should be reused. It should also reused
     /// in order to cancel a request.
-    pub request_id: String,
+    pub request_id: Box<TransactionId>,
 }
 
-impl RoomKeyRequestToDeviceEventContent {
-    /// Creates a new `RoomKeyRequestToDeviceEventContent` with the given action, boyd, device ID
+impl ToDeviceRoomKeyRequestEventContent {
+    /// Creates a new `ToDeviceRoomKeyRequestEventContent` with the given action, boyd, device ID
     /// and request ID.
     pub fn new(
         action: Action,
         body: Option<RequestedKeyInfo>,
-        requesting_device_id: DeviceIdBox,
-        request_id: String,
+        requesting_device_id: Box<DeviceId>,
+        request_id: Box<TransactionId>,
     ) -> Self {
         Self { action, body, requesting_device_id, request_id }
     }
@@ -57,7 +61,7 @@ pub enum Action {
     CancelRequest,
 
     #[doc(hidden)]
-    _Custom(String),
+    _Custom(PrivOwnedStr),
 }
 
 impl Action {
@@ -75,7 +79,7 @@ pub struct RequestedKeyInfo {
     pub algorithm: EventEncryptionAlgorithm,
 
     /// The room where the key is used.
-    pub room_id: RoomId,
+    pub room_id: Box<RoomId>,
 
     /// The Curve25519 key of the device which initiated the session originally.
     pub sender_key: String,
@@ -89,7 +93,7 @@ impl RequestedKeyInfo {
     /// ID.
     pub fn new(
         algorithm: EventEncryptionAlgorithm,
-        room_id: RoomId,
+        room_id: Box<RoomId>,
         sender_key: String,
         session_id: String,
     ) -> Self {
