@@ -1,4 +1,4 @@
-#![cfg(not(feature = "unstable-pre-spec"))]
+#![cfg(all(feature = "unstable-pdu", not(feature = "unstable-pre-spec")))]
 
 use std::{collections::BTreeMap, convert::TryInto};
 
@@ -8,40 +8,43 @@ use ruma_events::{
     EventType,
 };
 use ruma_identifiers::{event_id, room_id, server_name, server_signing_key_id, user_id};
-use serde_json::{from_value as from_json_value, json, to_value as to_json_value};
+use serde_json::{
+    from_value as from_json_value, json, to_value as to_json_value,
+    value::to_raw_value as to_raw_json_value,
+};
 
 #[test]
 fn serialize_pdu_as_v1() {
     let mut signatures = BTreeMap::new();
     let mut inner_signature = BTreeMap::new();
     inner_signature.insert(
-        server_signing_key_id!("ed25519:key_version"),
+        server_signing_key_id!("ed25519:key_version").to_owned(),
         "86BytesOfSignatureOfTheRedactedEvent".into(),
     );
-    signatures.insert(server_name!("example.com"), inner_signature);
+    signatures.insert(server_name!("example.com").to_owned(), inner_signature);
 
     let mut unsigned = BTreeMap::new();
-    unsigned.insert("somekey".into(), json!({"a": 456}));
+    unsigned.insert("somekey".into(), to_raw_json_value(&json!({ "a": 456 })).unwrap());
 
     let v1_pdu = RoomV1Pdu {
-        room_id: room_id!("!n8f893n9:example.com"),
-        event_id: event_id!("$somejoinevent:matrix.org"),
-        sender: user_id!("@sender:example.com"),
+        room_id: room_id!("!n8f893n9:example.com").to_owned(),
+        event_id: event_id!("$somejoinevent:matrix.org").to_owned(),
+        sender: user_id!("@sender:example.com").to_owned(),
         origin: "matrix.org".into(),
         origin_server_ts: MilliSecondsSinceUnixEpoch(1_592_050_773_658_u64.try_into().unwrap()),
         kind: EventType::RoomPowerLevels,
-        content: json!({"testing": 123}),
+        content: to_raw_json_value(&json!({ "testing": 123 })).unwrap(),
         state_key: Some("state".into()),
         prev_events: vec![(
-            event_id!("$previousevent:matrix.org"),
+            event_id!("$previousevent:matrix.org").to_owned(),
             EventHash::new("123567".into()),
         )],
         depth: 2_u32.into(),
         auth_events: vec![(
-            event_id!("$someauthevent:matrix.org"),
+            event_id!("$someauthevent:matrix.org").to_owned(),
             EventHash::new("21389CFEDABC".into()),
         )],
-        redacts: Some(event_id!("$9654:matrix.org")),
+        redacts: Some(event_id!("$9654:matrix.org").to_owned()),
         unsigned,
         hashes: EventHash::new("1233543bABACDEF".into()),
         signatures,
@@ -52,7 +55,7 @@ fn serialize_pdu_as_v1() {
         "event_id": "$somejoinevent:matrix.org",
         "sender": "@sender:example.com",
         "origin": "matrix.org",
-        "origin_server_ts": 1_592_050_773_658u64,
+        "origin_server_ts": 1_592_050_773_658_u64,
         "type": "m.room.power_levels",
         "content": {
             "testing": 123
@@ -82,26 +85,26 @@ fn serialize_pdu_as_v3() {
     let mut signatures = BTreeMap::new();
     let mut inner_signature = BTreeMap::new();
     inner_signature.insert(
-        server_signing_key_id!("ed25519:key_version"),
+        server_signing_key_id!("ed25519:key_version").to_owned(),
         "86BytesOfSignatureOfTheRedactedEvent".into(),
     );
-    signatures.insert(server_name!("example.com"), inner_signature);
+    signatures.insert(server_name!("example.com").to_owned(), inner_signature);
 
     let mut unsigned = BTreeMap::new();
-    unsigned.insert("somekey".into(), json!({ "a": 456 }));
+    unsigned.insert("somekey".into(), to_raw_json_value(&json!({ "a": 456 })).unwrap());
 
     let v3_pdu = RoomV3Pdu {
-        room_id: room_id!("!n8f893n9:example.com"),
-        sender: user_id!("@sender:example.com"),
+        room_id: room_id!("!n8f893n9:example.com").to_owned(),
+        sender: user_id!("@sender:example.com").to_owned(),
         origin: "matrix.org".into(),
         origin_server_ts: MilliSecondsSinceUnixEpoch(1_592_050_773_658_u64.try_into().unwrap()),
         kind: EventType::RoomPowerLevels,
-        content: json!({"testing": 123}),
+        content: to_raw_json_value(&json!({ "testing": 123 })).unwrap(),
         state_key: Some("state".into()),
-        prev_events: vec![event_id!("$previousevent:matrix.org")],
+        prev_events: vec![event_id!("$previousevent:matrix.org").to_owned()],
         depth: 2_u32.into(),
-        auth_events: vec![event_id!("$someauthevent:matrix.org")],
-        redacts: Some(event_id!("$9654:matrix.org")),
+        auth_events: vec![event_id!("$someauthevent:matrix.org").to_owned()],
+        redacts: Some(event_id!("$9654:matrix.org").to_owned()),
         unsigned,
         hashes: EventHash::new("1233543bABACDEF".into()),
         signatures,
@@ -111,7 +114,7 @@ fn serialize_pdu_as_v3() {
         "room_id": "!n8f893n9:example.com",
         "sender": "@sender:example.com",
         "origin": "matrix.org",
-        "origin_server_ts": 1_592_050_773_658u64,
+        "origin_server_ts": 1_592_050_773_658_u64,
         "type": "m.room.power_levels",
         "content": {
             "testing": 123
@@ -205,7 +208,6 @@ fn deserialize_pdu_as_v3() {
             "key": "value"
         },
         "depth": 12,
-        "event_id": "$a4ecee13e2accdadf56c1025:example.com",
         "hashes": {
             "sha256": "ThisHashCoversAllFieldsInCaseThisIsRedacted"
         },
@@ -233,7 +235,7 @@ fn deserialize_pdu_as_v3() {
     match parsed {
         Pdu::RoomV1Pdu(_) => panic!("Matched V1 PDU"),
         Pdu::RoomV3Pdu(v3_pdu) => {
-            assert_eq!(v3_pdu.auth_events.first().unwrap(), &event_id!("$abc123:matrix.org"));
+            assert_eq!(v3_pdu.auth_events.first().unwrap(), event_id!("$abc123:matrix.org"));
         }
         #[cfg(not(feature = "unstable-exhaustive-types"))]
         _ => unreachable!("new PDU version"),
