@@ -2,33 +2,31 @@ use js_int::uint;
 use matches::assert_matches;
 use ruma_common::MilliSecondsSinceUnixEpoch;
 use ruma_events::{
-    custom::RedactedCustomEventContent,
     room::{
-        aliases::RedactedAliasesEventContent,
-        create::RedactedCreateEventContent,
-        message::RedactedMessageEventContent,
-        redaction::{RedactionEventContent, SyncRedactionEvent},
+        aliases::RedactedRoomAliasesEventContent,
+        create::{RedactedRoomCreateEventContent, RoomCreateEventContent},
+        message::{RedactedRoomMessageEventContent, RoomMessageEventContent},
+        redaction::{RoomRedactionEventContent, SyncRoomRedactionEvent},
     },
-    AnyMessageEvent, AnyMessageEventContent, AnyRedactedMessageEvent,
-    AnyRedactedMessageEventContent, AnyRedactedStateEventContent, AnyRedactedSyncMessageEvent,
-    AnyRedactedSyncStateEvent, AnyRoomEvent, AnyStateEventContent, AnySyncRoomEvent, EventContent,
-    Redact, RedactContent, RedactedMessageEvent, RedactedSyncMessageEvent, RedactedSyncStateEvent,
-    RedactedUnsigned, Unsigned,
+    AnyMessageEvent, AnyRedactedMessageEvent, AnyRedactedSyncMessageEvent,
+    AnyRedactedSyncStateEvent, AnyRoomEvent, AnySyncRoomEvent, EventContent, Redact, RedactContent,
+    RedactedMessageEvent, RedactedSyncMessageEvent, RedactedSyncStateEvent, RedactedUnsigned,
+    Unsigned,
 };
 use ruma_identifiers::{event_id, room_id, user_id, RoomVersionId};
-use ruma_serde::Raw;
 use serde_json::{
-    from_value as from_json_value, json, to_value as to_json_value, value::to_raw_value,
+    from_value as from_json_value, json, to_value as to_json_value,
+    value::to_raw_value as to_raw_json_value,
 };
 
 fn unsigned() -> RedactedUnsigned {
     let mut unsigned = RedactedUnsigned::default();
-    unsigned.redacted_because = Some(Box::new(SyncRedactionEvent {
-        content: RedactionEventContent::with_reason("redacted because".into()),
-        redacts: event_id!("$h29iv0s8:example.com"),
-        event_id: event_id!("$h29iv0s8:example.com"),
+    unsigned.redacted_because = Some(Box::new(SyncRoomRedactionEvent {
+        content: RoomRedactionEventContent::with_reason("redacted because".into()),
+        redacts: event_id!("$h29iv0s8:example.com").to_owned(),
+        event_id: event_id!("$h29iv0s8:example.com").to_owned(),
         origin_server_ts: MilliSecondsSinceUnixEpoch(uint!(1)),
-        sender: user_id!("@carl:example.com"),
+        sender: user_id!("@carl:example.com").to_owned(),
         unsigned: Unsigned::default(),
     }));
 
@@ -38,10 +36,10 @@ fn unsigned() -> RedactedUnsigned {
 #[test]
 fn redacted_message_event_serialize() {
     let redacted = RedactedSyncMessageEvent {
-        content: RedactedMessageEventContent::new(),
-        event_id: event_id!("$h29iv0s8:example.com"),
+        content: RedactedRoomMessageEventContent::new(),
+        event_id: event_id!("$h29iv0s8:example.com").to_owned(),
         origin_server_ts: MilliSecondsSinceUnixEpoch(uint!(1)),
-        sender: user_id!("@carl:example.com"),
+        sender: user_id!("@carl:example.com").to_owned(),
         unsigned: RedactedUnsigned::default(),
     };
 
@@ -49,7 +47,7 @@ fn redacted_message_event_serialize() {
       "event_id": "$h29iv0s8:example.com",
       "origin_server_ts": 1,
       "sender": "@carl:example.com",
-      "type": "m.room.message"
+      "type": "m.room.message",
     });
 
     let actual = to_json_value(&redacted).unwrap();
@@ -59,11 +57,11 @@ fn redacted_message_event_serialize() {
 #[test]
 fn redacted_aliases_event_serialize_no_content() {
     let redacted = RedactedSyncStateEvent {
-        content: RedactedAliasesEventContent::default(),
-        event_id: event_id!("$h29iv0s8:example.com"),
+        content: RedactedRoomAliasesEventContent::default(),
+        event_id: event_id!("$h29iv0s8:example.com").to_owned(),
         state_key: "".into(),
         origin_server_ts: MilliSecondsSinceUnixEpoch(uint!(1)),
-        sender: user_id!("@carl:example.com"),
+        sender: user_id!("@carl:example.com").to_owned(),
         unsigned: RedactedUnsigned::default(),
     };
 
@@ -72,7 +70,7 @@ fn redacted_aliases_event_serialize_no_content() {
       "state_key": "",
       "origin_server_ts": 1,
       "sender": "@carl:example.com",
-      "type": "m.room.aliases"
+      "type": "m.room.aliases",
     });
 
     let actual = to_json_value(&redacted).unwrap();
@@ -82,11 +80,11 @@ fn redacted_aliases_event_serialize_no_content() {
 #[test]
 fn redacted_aliases_event_serialize_with_content() {
     let redacted = RedactedSyncStateEvent {
-        content: RedactedAliasesEventContent::new_v1(vec![]),
-        event_id: event_id!("$h29iv0s8:example.com"),
+        content: RedactedRoomAliasesEventContent::new_v1(vec![]),
+        event_id: event_id!("$h29iv0s8:example.com").to_owned(),
         state_key: "".to_owned(),
         origin_server_ts: MilliSecondsSinceUnixEpoch(uint!(1)),
-        sender: user_id!("@carl:example.com"),
+        sender: user_id!("@carl:example.com").to_owned(),
         unsigned: RedactedUnsigned::default(),
     };
 
@@ -98,7 +96,7 @@ fn redacted_aliases_event_serialize_with_content() {
       "state_key": "",
       "origin_server_ts": 1,
       "sender": "@carl:example.com",
-      "type": "m.room.aliases"
+      "type": "m.room.aliases",
     });
 
     let actual = to_json_value(&redacted).unwrap();
@@ -113,19 +111,16 @@ fn redacted_aliases_deserialize() {
       "sender": "@carl:example.com",
       "state_key": "hello",
       "unsigned": unsigned(),
-      "type": "m.room.aliases"
+      "type": "m.room.aliases",
     });
 
     let actual = to_json_value(&redacted).unwrap();
 
     assert_matches!(
-        from_json_value::<Raw<AnySyncRoomEvent>>(actual)
-            .unwrap()
-            .deserialize()
-            .unwrap(),
+        from_json_value::<AnySyncRoomEvent>(actual).unwrap(),
         AnySyncRoomEvent::RedactedState(AnyRedactedSyncStateEvent::RoomAliases(
             RedactedSyncStateEvent {
-                content: RedactedAliasesEventContent { aliases, .. },
+                content: RedactedRoomAliasesEventContent { aliases, .. },
                 event_id,
                 ..
             },
@@ -142,18 +137,15 @@ fn redacted_deserialize_any_room() {
       "origin_server_ts": 1,
       "sender": "@carl:example.com",
       "unsigned": unsigned(),
-      "type": "m.room.message"
+      "type": "m.room.message",
     });
 
     let actual = to_json_value(&redacted).unwrap();
 
     assert_matches!(
-        from_json_value::<Raw<AnyRoomEvent>>(actual)
-            .unwrap()
-            .deserialize()
-            .unwrap(),
+        from_json_value::<AnyRoomEvent>(actual).unwrap(),
         AnyRoomEvent::RedactedMessage(AnyRedactedMessageEvent::RoomMessage(RedactedMessageEvent {
-            content: RedactedMessageEventContent { .. },
+            content: RedactedRoomMessageEventContent { .. },
             event_id, room_id, ..
         })) if event_id == event_id!("$h29iv0s8:example.com")
             && room_id == room_id!("!roomid:room.com")
@@ -166,12 +158,12 @@ fn redacted_deserialize_any_room_sync() {
     // The presence of `redacted_because` triggers the event enum (AnySyncRoomEvent in this case)
     // to return early with `RedactedContent` instead of failing to deserialize according
     // to the event type string.
-    unsigned.redacted_because = Some(Box::new(SyncRedactionEvent {
-        content: RedactionEventContent::with_reason("redacted because".into()),
-        redacts: event_id!("$h29iv0s8:example.com"),
-        event_id: event_id!("$h29iv0s8:example.com"),
+    unsigned.redacted_because = Some(Box::new(SyncRoomRedactionEvent {
+        content: RoomRedactionEventContent::with_reason("redacted because".into()),
+        redacts: event_id!("$h29iv0s8:example.com").to_owned(),
+        event_id: event_id!("$h29iv0s8:example.com").to_owned(),
         origin_server_ts: MilliSecondsSinceUnixEpoch(uint!(1)),
-        sender: user_id!("@carl:example.com"),
+        sender: user_id!("@carl:example.com").to_owned(),
         unsigned: Unsigned::default(),
     }));
 
@@ -180,19 +172,16 @@ fn redacted_deserialize_any_room_sync() {
       "origin_server_ts": 1,
       "sender": "@carl:example.com",
       "unsigned": unsigned,
-      "type": "m.room.message"
+      "type": "m.room.message",
     });
 
     let actual = to_json_value(&redacted).unwrap();
 
     assert_matches!(
-        from_json_value::<Raw<AnySyncRoomEvent>>(actual)
-            .unwrap()
-            .deserialize()
-            .unwrap(),
+        from_json_value::<AnySyncRoomEvent>(actual).unwrap(),
         AnySyncRoomEvent::RedactedMessage(AnyRedactedSyncMessageEvent::RoomMessage(
             RedactedSyncMessageEvent {
-                content: RedactedMessageEventContent { .. },
+                content: RedactedRoomMessageEventContent { .. },
                 event_id,
                 ..
             }
@@ -211,17 +200,15 @@ fn redacted_state_event_deserialize() {
       "sender": "@carl:example.com",
       "state_key": "hello there",
       "unsigned": unsigned(),
-      "type": "m.room.create"
+      "type": "m.room.create",
     });
 
     assert_matches!(
-        from_json_value::<Raw<AnySyncRoomEvent>>(redacted)
-            .unwrap()
-            .deserialize()
+        from_json_value::<AnySyncRoomEvent>(redacted)
             .unwrap(),
         AnySyncRoomEvent::RedactedState(AnyRedactedSyncStateEvent::RoomCreate(
             RedactedSyncStateEvent {
-                content: RedactedCreateEventContent {
+                content: RedactedRoomCreateEventContent {
                     creator, ..
                 },
                 event_id,
@@ -244,7 +231,7 @@ fn redacted_custom_event_serialize() {
         "sender": "@carl:example.com",
         "state_key": "hello there",
         "unsigned": unsigned(),
-        "type": "m.made.up"
+        "type": "m.made.up",
     });
 
     assert_matches!(
@@ -253,33 +240,7 @@ fn redacted_custom_event_serialize() {
     );
 
     let x = from_json_value::<AnyRedactedSyncStateEvent>(redacted).unwrap();
-    assert_eq!(x.event_id(), &event_id!("$h29iv0s8:example.com"))
-}
-
-#[test]
-fn redacted_custom_event_deserialize() {
-    let unsigned = unsigned();
-
-    let redacted = RedactedSyncStateEvent {
-        content: RedactedCustomEventContent { event_type: "m.made.up".into() },
-        event_id: event_id!("$h29iv0s8:example.com"),
-        sender: user_id!("@carl:example.com"),
-        state_key: "hello there".into(),
-        origin_server_ts: MilliSecondsSinceUnixEpoch(uint!(1)),
-        unsigned: unsigned.clone(),
-    };
-
-    let expected = json!({
-      "event_id": "$h29iv0s8:example.com",
-      "origin_server_ts": 1,
-      "sender": "@carl:example.com",
-      "state_key": "hello there",
-      "unsigned": unsigned,
-      "type": "m.made.up"
-    });
-
-    let actual = to_json_value(&redacted).unwrap();
-    assert_eq!(actual, expected);
+    assert_eq!(x.event_id(), event_id!("$h29iv0s8:example.com"))
 }
 
 #[test]
@@ -294,24 +255,24 @@ fn redact_method_properly_redacts() {
             "body": "test",
             "msgtype": "m.audio",
             "url": "mxc://example.com/AuDi0",
-        }
+        },
     });
 
-    let redaction = SyncRedactionEvent {
-        content: RedactionEventContent::with_reason("redacted because".into()),
-        redacts: event_id!("$143273582443PhrSn:example.com"),
-        event_id: event_id!("$h29iv0s8:example.com"),
+    let redaction = SyncRoomRedactionEvent {
+        content: RoomRedactionEventContent::with_reason("redacted because".into()),
+        redacts: event_id!("$143273582443PhrSn:example.com").to_owned(),
+        event_id: event_id!("$h29iv0s8:example.com").to_owned(),
         origin_server_ts: MilliSecondsSinceUnixEpoch(uint!(1)),
-        sender: user_id!("@carl:example.com"),
+        sender: user_id!("@carl:example.com").to_owned(),
         unsigned: Unsigned::default(),
     };
 
-    let event = from_json_value::<Raw<AnyMessageEvent>>(ev).unwrap().deserialize().unwrap();
+    let event: AnyMessageEvent = from_json_value(ev).unwrap();
 
     assert_matches!(
-        event.redact(redaction, &RoomVersionId::Version6),
+        event.redact(redaction, &RoomVersionId::V6),
         AnyRedactedMessageEvent::RoomMessage(RedactedMessageEvent {
-            content: RedactedMessageEventContent { .. },
+            content: RedactedRoomMessageEventContent { .. },
             event_id,
             room_id,
             sender,
@@ -333,13 +294,10 @@ fn redact_message_content() {
         "url": "mxc://example.com/AuDi0",
     });
 
-    let raw_json = to_raw_value(&json).unwrap();
-    let content = AnyMessageEventContent::from_parts("m.room.message", &raw_json).unwrap();
+    let raw_json = to_raw_json_value(&json).unwrap();
+    let content = RoomMessageEventContent::from_parts("m.room.message", &raw_json).unwrap();
 
-    assert_matches!(
-        content.redact(&RoomVersionId::Version6),
-        AnyRedactedMessageEventContent::RoomMessage(RedactedMessageEventContent { .. })
-    );
+    assert_matches!(content.redact(&RoomVersionId::V6), RedactedRoomMessageEventContent { .. });
 }
 
 #[test]
@@ -347,17 +305,17 @@ fn redact_state_content() {
     let json = json!({
         "creator": "@carl:example.com",
         "m.federate": true,
-        "room_version": "4"
+        "room_version": "4",
     });
 
-    let raw_json = to_raw_value(&json).unwrap();
-    let content = AnyStateEventContent::from_parts("m.room.create", &raw_json).unwrap();
+    let raw_json = to_raw_json_value(&json).unwrap();
+    let content = RoomCreateEventContent::from_parts("m.room.create", &raw_json).unwrap();
 
     assert_matches!(
-        content.redact(&RoomVersionId::Version6),
-        AnyRedactedStateEventContent::RoomCreate(RedactedCreateEventContent {
+        content.redact(&RoomVersionId::V6),
+        RedactedRoomCreateEventContent {
             creator,
             ..
-        }) if creator == user_id!("@carl:example.com")
+        } if creator == user_id!("@carl:example.com")
     );
 }
