@@ -4,21 +4,15 @@ use assign::assign;
 use js_int::uint;
 use matches::assert_matches;
 use ruma_common::MilliSecondsSinceUnixEpoch;
-#[cfg(feature = "unstable-pre-spec")]
-use ruma_events::{
-    key::verification::VerificationMethod, room::message::KeyVerificationRequestEventContent,
-};
 use ruma_events::{
+    key::verification::VerificationMethod,
     room::message::{
-        AudioMessageEventContent, InReplyTo, MessageEvent, MessageEventContent, MessageType,
-        Relation, TextMessageEventContent,
+        AudioMessageEventContent, InReplyTo, KeyVerificationRequestEventContent, MessageType,
+        Relation, RoomMessageEvent, RoomMessageEventContent, TextMessageEventContent,
     },
     Unsigned,
 };
-#[cfg(feature = "unstable-pre-spec")]
-use ruma_identifiers::DeviceIdBox;
-use ruma_identifiers::{event_id, mxc_uri, room_id, user_id};
-use ruma_serde::Raw;
+use ruma_identifiers::{event_id, mxc_uri, room_id, user_id, DeviceId};
 use serde_json::{from_value as from_json_value, json, to_value as to_json_value};
 
 macro_rules! json_object {
@@ -35,16 +29,16 @@ macro_rules! json_object {
 
 #[test]
 fn serialization() {
-    let ev = MessageEvent {
-        content: MessageEventContent::new(MessageType::Audio(AudioMessageEventContent::plain(
+    let ev = RoomMessageEvent {
+        content: RoomMessageEventContent::new(MessageType::Audio(AudioMessageEventContent::plain(
             "test".into(),
-            mxc_uri!("mxc://example.org/ffed755USFFxlgbQYZGtryd"),
+            mxc_uri!("mxc://example.org/ffed755USFFxlgbQYZGtryd").to_owned(),
             None,
         ))),
-        event_id: event_id!("$143273582443PhrSn:example.org"),
+        event_id: event_id!("$143273582443PhrSn:example.org").to_owned(),
         origin_server_ts: MilliSecondsSinceUnixEpoch(uint!(10_000)),
-        room_id: room_id!("!testroomid:example.org"),
-        sender: user_id!("@user:example.org"),
+        room_id: room_id!("!testroomid:example.org").to_owned(),
+        sender: user_id!("@user:example.org").to_owned(),
         unsigned: Unsigned::default(),
     };
 
@@ -68,9 +62,9 @@ fn serialization() {
 #[test]
 fn content_serialization() {
     let message_event_content =
-        MessageEventContent::new(MessageType::Audio(AudioMessageEventContent::plain(
+        RoomMessageEventContent::new(MessageType::Audio(AudioMessageEventContent::plain(
             "test".into(),
-            mxc_uri!("mxc://example.org/ffed755USFFxlgbQYZGtryd"),
+            mxc_uri!("mxc://example.org/ffed755USFFxlgbQYZGtryd").to_owned(),
             None,
         )));
 
@@ -90,12 +84,14 @@ fn custom_msgtype_serialization() {
         "custom_field".into() => json!("baba"),
         "another_one".into() => json!("abab"),
     };
-    let custom_msgtype = MessageType::new("my_custom_msgtype", json_data).unwrap();
+    let custom_msgtype =
+        MessageType::new("my_custom_msgtype", "my message body".into(), json_data).unwrap();
 
     assert_eq!(
         to_json_value(&custom_msgtype).unwrap(),
         json!({
             "msgtype": "my_custom_msgtype",
+            "body": "my message body",
             "custom_field": "baba",
             "another_one": "abab",
         })
@@ -106,6 +102,7 @@ fn custom_msgtype_serialization() {
 fn custom_content_deserialization() {
     let json_data = json!({
         "msgtype": "my_custom_msgtype",
+        "body": "my custom message",
         "custom_field": "baba",
         "another_one": "abab",
     });
@@ -115,17 +112,17 @@ fn custom_content_deserialization() {
         "another_one".into() => json!("abab"),
     };
 
-    let custom_event =
-        from_json_value::<Raw<MessageType>>(json_data).unwrap().deserialize().unwrap();
+    let custom_event: MessageType = from_json_value(json_data).unwrap();
 
     assert_eq!(custom_event.msgtype(), "my_custom_msgtype");
+    assert_eq!(custom_event.body(), "my custom message");
     assert_eq!(custom_event.data(), Cow::Owned(expected_json_data));
 }
 
 #[test]
 fn formatted_body_serialization() {
     let message_event_content =
-        MessageEventContent::text_html("Hello, World!", "Hello, <em>World</em>!");
+        RoomMessageEventContent::text_html("Hello, World!", "Hello, <em>World</em>!");
 
     assert_eq!(
         to_json_value(&message_event_content).unwrap(),
@@ -141,7 +138,7 @@ fn formatted_body_serialization() {
 #[test]
 fn plain_text_content_serialization() {
     let message_event_content =
-        MessageEventContent::text_plain("> <@test:example.com> test\n\ntest reply");
+        RoomMessageEventContent::text_plain("> <@test:example.com> test\n\ntest reply");
 
     assert_eq!(
         to_json_value(&message_event_content).unwrap(),
@@ -155,7 +152,7 @@ fn plain_text_content_serialization() {
 #[test]
 #[cfg(feature = "markdown")]
 fn markdown_content_serialization() {
-    let formatted_message = MessageEventContent::new(MessageType::Text(
+    let formatted_message = RoomMessageEventContent::new(MessageType::Text(
         TextMessageEventContent::markdown("Testing **bold** and _italic_!"),
     ));
 
@@ -169,7 +166,7 @@ fn markdown_content_serialization() {
         })
     );
 
-    let plain_message_simple = MessageEventContent::new(MessageType::Text(
+    let plain_message_simple = RoomMessageEventContent::new(MessageType::Text(
         TextMessageEventContent::markdown("Testing a simple phrase…"),
     ));
 
@@ -181,7 +178,7 @@ fn markdown_content_serialization() {
         })
     );
 
-    let plain_message_paragraphs = MessageEventContent::new(MessageType::Text(
+    let plain_message_paragraphs = RoomMessageEventContent::new(MessageType::Text(
         TextMessageEventContent::markdown("Testing\n\nSeveral\n\nParagraphs."),
     ));
 
@@ -199,9 +196,11 @@ fn markdown_content_serialization() {
 #[test]
 fn relates_to_content_serialization() {
     let message_event_content =
-        assign!(MessageEventContent::text_plain("> <@test:example.com> test\n\ntest reply"), {
+        assign!(RoomMessageEventContent::text_plain("> <@test:example.com> test\n\ntest reply"), {
             relates_to: Some(Relation::Reply {
-                in_reply_to: InReplyTo::new(event_id!("$15827405538098VGFWH:example.com")),
+                in_reply_to: InReplyTo::new(
+                    event_id!("$15827405538098VGFWH:example.com").to_owned(),
+                ),
             }),
         });
 
@@ -219,7 +218,7 @@ fn relates_to_content_serialization() {
 }
 
 #[test]
-#[cfg(not(feature = "unstable-pre-spec"))]
+#[cfg(not(feature = "unstable-msc2676"))]
 fn edit_deserialization_061() {
     let json_data = json!({
         "body": "s/foo/bar",
@@ -234,21 +233,21 @@ fn edit_deserialization_061() {
     });
 
     assert_matches!(
-        from_json_value::<MessageEventContent>(json_data).unwrap(),
-        MessageEventContent {
+        from_json_value::<RoomMessageEventContent>(json_data).unwrap(),
+        RoomMessageEventContent {
             msgtype: MessageType::Text(TextMessageEventContent {
                 body,
                 formatted: None,
                 ..
             }),
-            relates_to: None,
+            relates_to: Some(_),
             ..
         } if body == "s/foo/bar"
     );
 }
 
 #[test]
-#[cfg(feature = "unstable-pre-spec")]
+#[cfg(feature = "unstable-msc2676")]
 fn edit_deserialization_future() {
     use ruma_events::room::message::Replacement;
 
@@ -267,8 +266,8 @@ fn edit_deserialization_future() {
     });
 
     assert_matches!(
-        from_json_value::<MessageEventContent>(json_data).unwrap(),
-        MessageEventContent {
+        from_json_value::<RoomMessageEventContent>(json_data).unwrap(),
+        RoomMessageEventContent {
             msgtype: MessageType::Text(TextMessageEventContent {
                 body,
                 formatted: None,
@@ -280,7 +279,7 @@ fn edit_deserialization_future() {
             && event_id == ev_id
             && matches!(
                 &*new_content,
-                MessageEventContent {
+                RoomMessageEventContent {
                     msgtype: MessageType::Text(TextMessageEventContent {
                         body,
                         formatted: None,
@@ -293,10 +292,9 @@ fn edit_deserialization_future() {
 }
 
 #[test]
-#[cfg(feature = "unstable-pre-spec")]
 fn verification_request_deserialization() {
     let user_id = user_id!("@example2:localhost");
-    let device_id: DeviceIdBox = "XOWLHHFSWM".into();
+    let device_id: Box<DeviceId> = "XOWLHHFSWM".into();
 
     let json_data = json!({
         "body": "@example:localhost is requesting to verify your key, ...",
@@ -311,8 +309,8 @@ fn verification_request_deserialization() {
     });
 
     assert_matches!(
-        from_json_value::<MessageEventContent>(json_data).unwrap(),
-        MessageEventContent {
+        from_json_value::<RoomMessageEventContent>(json_data).unwrap(),
+        RoomMessageEventContent {
             msgtype: MessageType::VerificationRequest(KeyVerificationRequestEventContent {
                 body,
                 to,
@@ -329,17 +327,13 @@ fn verification_request_deserialization() {
 }
 
 #[test]
-#[cfg(feature = "unstable-pre-spec")]
 fn verification_request_serialization() {
-    let user_id = user_id!("@example2:localhost");
-    let device_id: DeviceIdBox = "XOWLHHFSWM".into();
+    let user_id = user_id!("@example2:localhost").to_owned();
+    let device_id: Box<DeviceId> = "XOWLHHFSWM".into();
     let body = "@example:localhost is requesting to verify your key, ...".to_owned();
 
-    let methods = vec![
-        VerificationMethod::SasV1,
-        VerificationMethod::_Custom("m.qr_code.show.v1".to_owned()),
-        VerificationMethod::_Custom("m.reciprocate.v1".to_owned()),
-    ];
+    let methods =
+        vec![VerificationMethod::SasV1, "m.qr_code.show.v1".into(), "m.reciprocate.v1".into()];
 
     let json_data = json!({
         "body": body,
@@ -365,11 +359,9 @@ fn content_deserialization() {
     });
 
     assert_matches!(
-        from_json_value::<Raw<MessageEventContent>>(json_data)
-            .unwrap()
-            .deserialize()
+        from_json_value::<RoomMessageEventContent>(json_data)
             .unwrap(),
-        MessageEventContent {
+        RoomMessageEventContent {
             msgtype: MessageType::Audio(AudioMessageEventContent {
                 body,
                 info: None,
@@ -378,7 +370,7 @@ fn content_deserialization() {
                 ..
             }),
             ..
-        } if body == "test" && url.to_string() == "mxc://example.org/ffed755USFFxlgbQYZGtryd"
+        } if body == "test" && url == "mxc://example.org/ffed755USFFxlgbQYZGtryd"
     );
 }
 
@@ -388,5 +380,5 @@ fn content_deserialization_failure() {
         "body": "test","msgtype": "m.location",
         "url": "http://example.com/audio.mp3"
     });
-    assert!(from_json_value::<Raw<MessageEventContent>>(json_data).unwrap().deserialize().is_err());
+    assert!(from_json_value::<RoomMessageEventContent>(json_data).is_err());
 }
