@@ -2,18 +2,18 @@ use std::convert::TryFrom;
 
 use js_int::uint;
 use ruma_events::{
-    room::{join_rules::JoinRule, topic::TopicEventContent},
-    AnyStateEventContent, AnyStrippedStateEvent, StrippedStateEvent,
+    room::{join_rules::JoinRule, topic::RoomTopicEventContent},
+    AnyStrippedStateEvent, StrippedStateEvent,
 };
-use ruma_identifiers::{mxc_uri, user_id, RoomNameBox};
+use ruma_identifiers::{mxc_uri, user_id, RoomName};
 use serde_json::{from_value as from_json_value, json, to_value as to_json_value};
 
 #[test]
 fn serialize_stripped_state_event_any_content() {
     let event = StrippedStateEvent {
-        content: AnyStateEventContent::RoomTopic(TopicEventContent::new("Testing room".into())),
+        content: RoomTopicEventContent::new("Testing room".into()),
         state_key: "".into(),
-        sender: user_id!("@example:localhost"),
+        sender: user_id!("@example:localhost").to_owned(),
     };
 
     let json_data = json!({
@@ -28,26 +28,6 @@ fn serialize_stripped_state_event_any_content() {
     assert_eq!(to_json_value(&event).unwrap(), json_data);
 }
 
-#[test]
-fn serialize_stripped_state_event_any_event() {
-    let event = AnyStrippedStateEvent::RoomTopic(StrippedStateEvent {
-        content: TopicEventContent::new("Testing room".into()),
-        state_key: "".into(),
-        sender: user_id!("@example:localhost"),
-    });
-
-    let json_data = json!({
-        "content": {
-            "topic": "Testing room"
-        },
-        "type": "m.room.topic",
-        "state_key": "",
-        "sender": "@example:localhost"
-    });
-
-    assert_eq!(to_json_value(&event).unwrap(), json_data);
-}
-
 #[test]
 fn deserialize_stripped_state_events() {
     let name_event = json!({
@@ -96,7 +76,7 @@ fn deserialize_stripped_state_events() {
     let event = from_json_value::<AnyStrippedStateEvent>(name_event).unwrap();
     match event {
         AnyStrippedStateEvent::RoomName(event) => {
-            assert_eq!(event.content.name, Some(RoomNameBox::try_from("Ruma").unwrap()));
+            assert_eq!(event.content.name, Some(Box::<RoomName>::try_from("Ruma").unwrap()));
             assert_eq!(event.state_key, "");
             assert_eq!(event.sender.to_string(), "@example:localhost");
         }
@@ -120,7 +100,7 @@ fn deserialize_stripped_state_events() {
             let expected_url = mxc_uri!("mxc://example.com/iMag3");
 
             #[cfg(feature = "unstable-pre-spec")]
-            let expected_url = Some(expected_url);
+            let expected_url = Some(expected_url.to_owned());
 
             assert_eq!(image_info.height.unwrap(), uint!(128));
             assert_eq!(image_info.width.unwrap(), uint!(128));
