@@ -1,17 +1,17 @@
-use ruma_events::{room_key::RoomKeyToDeviceEventContent, AnyToDeviceEventContent, ToDeviceEvent};
+use ruma_events::{room_key::ToDeviceRoomKeyEventContent, ToDeviceEvent};
 use ruma_identifiers::{room_id, user_id, EventEncryptionAlgorithm};
 use serde_json::{json, to_value as to_json_value};
 
 #[test]
 fn serialization() {
     let ev = ToDeviceEvent {
-        sender: user_id!("@example:example.org"),
-        content: AnyToDeviceEventContent::RoomKey(RoomKeyToDeviceEventContent::new(
+        sender: user_id!("@example:example.org").to_owned(),
+        content: ToDeviceRoomKeyEventContent::new(
             EventEncryptionAlgorithm::MegolmV1AesSha2,
-            room_id!("!testroomid:example.org"),
+            room_id!("!testroomid:example.org").to_owned(),
             "SessId".into(),
             "SessKey".into(),
-        )),
+        ),
     };
 
     assert_eq!(
