@@ -3,7 +3,7 @@ use serde::{Deserialize, Serialize};
 
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
 #[ruma_event(type = "m.macro.test", kind = State)]
-pub struct MacroTest {
+pub struct MacroTestContent {
     pub url: String,
 }
 
